@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2013 John W. Eaton
-Copyright (C) 2011-2013 Jacob Dawid
+Copyright (C) 2013-2016 John W. Eaton
+Copyright (C) 2011-2016 Jacob Dawid
 
 This file is part of Octave.
 
@@ -21,18 +21,19 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
-#include <string>
-
-#include <signal.h>
-
 #include "octave.h"
 
 #include "octave-interpreter.h"
 
+octave_interpreter::octave_interpreter (octave::application *app_context)
+  : QObject (), thread_manager (), m_app_context (app_context),
+    m_exit_status (0)
+{ }
+
 void
 octave_interpreter::execute (void)
 {
@@ -40,10 +41,13 @@ octave_interpreter::execute (void)
 
   octave_thread_manager::unblock_interrupt_signal ();
 
-  octave_initialize_interpreter (octave_cmdline_argc, octave_cmdline_argv,
-                                 octave_embedded);
+  // The application context owns the interpreter.
 
-  octave_execute_interpreter ();
+  m_app_context->create_interpreter ();
+
+  emit octave_ready_signal ();
+
+  m_exit_status = m_app_context->execute_interpreter ();
 }
 
 void
@@ -51,3 +55,4 @@ octave_interpreter::interrupt (void)
 {
   thread_manager.interrupt ();
 }
+
