@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2011-2013 Jacob Dawid
+Copyright (C) 2011-2016 Jacob Dawid
 
 This file is part of Octave.
 
@@ -20,11 +20,12 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifndef RESOURCEMANAGER_H
-#define RESOURCEMANAGER_H
+#if ! defined (octave_resource_manager_h)
+#define octave_resource_manager_h 1
 
 #include <QDesktopServices>
 #include <QIcon>
+#include <QComboBox>
 #include <QMap>
 #include <QSettings>
 #include <QTranslator>
@@ -46,6 +47,14 @@ public:
     return instance_ok () ? instance->do_get_settings () : 0;
   }
 
+  static QIcon icon (const QString& icon_name, bool fallback = true)
+  {
+    if (instance_ok ())
+      return instance->do_icon (icon_name, fallback);
+
+    return QIcon ();
+  }
+
   static QSettings *get_default_settings (void)
   {
     return instance_ok () ? instance->do_get_default_settings () : 0;
@@ -68,6 +77,12 @@ public:
       instance->do_set_settings (file);
   }
 
+  static void combo_encoding (QComboBox *combo, QString current = QString ())
+  {
+    if (instance_ok ())
+      instance->do_combo_encoding (combo, current);
+  }
+
   static QString get_gui_translation_dir (void);
 
   static void config_translators (QTranslator*, QTranslator*, QTranslator*);
@@ -91,18 +106,16 @@ public:
   static QStringList terminal_color_names (void);
   static QList<QColor> terminal_default_colors (void);
 
-private:
-
   static resource_manager *instance;
 
+public slots:
+
   static void cleanup_instance (void) { delete instance; instance = 0; }
 
+private:
+
   // No copying!
 
-  resource_manager (const resource_manager&);
-
-  resource_manager& operator = (const resource_manager&);
-
   static bool instance_ok (void);
 
   QString settings_directory;
@@ -129,6 +142,10 @@ private:
 
   bool do_is_first_run (void) const;
 
+  QIcon do_icon (const QString& icon, bool fallback);
+
+  void do_combo_encoding (QComboBox *combo, QString current);
 };
 
-#endif // RESOURCEMANAGER_H
+#endif
+
