@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2013 John W. Eaton
-Copyright (C) 2011-2012 Jacob Dawid
+Copyright (C) 2013-2016 John W. Eaton
+Copyright (C) 2011-2016 Jacob Dawid
 
 This file is part of Octave.
 
@@ -21,8 +21,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifndef TERMINALDOCKWIDGET_H
-#define TERMINALDOCKWIDGET_H
+#if ! defined (octave_terminal_dock_widget_h)
+#define octave_terminal_dock_widget_h 1
 
 #include <QString>
 
@@ -37,13 +37,24 @@ public:
 
   terminal_dock_widget (QWidget *parent = 0);
 
+  ~terminal_dock_widget (void);
+
   bool has_focus (void) const;
 
   void focus (void);
 
+signals:
+
+  void interrupt_signal (void);
+
+protected slots:
+
+  void terminal_interrupt (void);
+
 private:
 
   QTerminal *terminal;
 };
 
-#endif // TERMINALDOCKWIDGET_H
+#endif
+
