@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2013 John W. Eaton
-Copyright (C) 2011-2012 Jacob Dawid
+Copyright (C) 2013-2016 John W. Eaton
+Copyright (C) 2011-2016 Jacob Dawid
 
 This file is part of Octave.
 
@@ -21,8 +21,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#if !defined (workspace_model_h)
-#define workspace_model_h 1
+#if ! defined (octave_workspace_model_h)
+#define octave_workspace_model_h 1
 
 #include <QAbstractTableModel>
 #include <QVector>
@@ -33,6 +33,9 @@ along with Octave; see the file COPYING.  If not, see
 #include <QColor>
 #include <QSettings>
 
+// Defined for purposes of sending QList<int> as part of signal.
+typedef QList<int> QIntList;
+
 class workspace_model
   : public QAbstractTableModel
 {
@@ -64,16 +67,19 @@ public:
 
   bool is_top_level (void) const { return _top_level; }
 
-  QColor storage_class_color (int s_class) { return _storage_class_colors.at (s_class); }
+  QColor storage_class_color (int s_class)
+  { return _storage_class_colors.at (s_class); }
 
 public slots:
 
   void set_workspace (bool top_level,
+                      bool debug,
                       const QString& scopes,
                       const QStringList& symbols,
                       const QStringList& class_names,
                       const QStringList& dimensions,
-                      const QStringList& values);
+                      const QStringList& values,
+                      const QIntList& complex_flags);
 
   void clear_workspace (void);
 
@@ -96,6 +102,7 @@ private:
   QStringList _class_names;
   QStringList _dimensions;
   QStringList _values;
+  QIntList _complex_flags;
 
   QStringList _columnNames;
 
@@ -104,3 +111,4 @@ private:
 };
 
 #endif
+
