@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2013 John W. Eaton
+Copyright (C) 1996-2016 John W. Eaton
 Copyright (C) 2008-2009 Jaroslav Hajek
 
 This file is part of Octave.
@@ -23,80 +23,78 @@ along with Octave; see the file COPYING.  If not, see
 
 // Author: A. S. Hodel <scotte@eng.auburn.edu>
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include <string>
 
-#include "CmplxAEPBAL.h"
-#include "fCmplxAEPBAL.h"
-#include "dbleAEPBAL.h"
-#include "floatAEPBAL.h"
-#include "CmplxGEPBAL.h"
-#include "fCmplxGEPBAL.h"
-#include "dbleGEPBAL.h"
-#include "floatGEPBAL.h"
+#include "CMatrix.h"
+#include "aepbalance.h"
+#include "dMatrix.h"
+#include "fCMatrix.h"
+#include "fMatrix.h"
+#include "gepbalance.h"
 #include "quit.h"
 
 #include "defun.h"
 #include "error.h"
 #include "f77-fcn.h"
-#include "gripes.h"
-#include "oct-obj.h"
+#include "errwarn.h"
+#include "ovl.h"
 #include "utils.h"
 
 DEFUN (balance, args, nargout,
-       "-*- texinfo -*-\n\
-@deftypefn  {Built-in Function} {@var{AA} =} balance (@var{A})\n\
-@deftypefnx {Built-in Function} {@var{AA} =} balance (@var{A}, @var{opt})\n\
-@deftypefnx {Built-in Function} {[@var{DD}, @var{AA}] =} balance (@var{A}, @var{opt})\n\
-@deftypefnx {Built-in Function} {[@var{D}, @var{P}, @var{AA}] =} balance (@var{A}, @var{opt})\n\
-@deftypefnx {Built-in Function} {[@var{CC}, @var{DD}, @var{AA}, @var{BB}] =} balance (@var{A}, @var{B}, @var{opt})\n\
-\n\
-Compute @code{@var{AA} = @var{DD} \\ @var{A} * @var{DD}} in which @var{AA}\n\
-is a matrix whose row and column norms are roughly equal in magnitude, and\n\
-@code{@var{DD} = @var{P} * @var{D}}, in which @var{P} is a permutation\n\
-matrix and @var{D} is a diagonal matrix of powers of two.  This allows the\n\
-equilibration to be computed without round-off.  Results of eigenvalue\n\
-calculation are typically improved by balancing first.\n\
-\n\
-If two output values are requested, @code{balance} returns\n\
-the diagonal @var{D} and the permutation @var{P} separately as vectors.\n\
-In this case, @code{@var{DD} = eye(n)(:,@var{P}) * diag (@var{D})}, where\n\
-@math{n} is the matrix size.\n\
-\n\
-If four output values are requested, compute @code{@var{AA} =\n\
-@var{CC}*@var{A}*@var{DD}} and @code{@var{BB} = @var{CC}*@var{B}*@var{DD}},\n\
-in which @var{AA} and @var{BB} have non-zero elements of approximately the\n\
-same magnitude and @var{CC} and @var{DD} are permuted diagonal matrices as\n\
-in @var{DD} for the algebraic eigenvalue problem.\n\
-\n\
-The eigenvalue balancing option @var{opt} may be one of:\n\
-\n\
-@table @asis\n\
-@item @qcode{\"noperm\"}, @qcode{\"S\"}\n\
-Scale only; do not permute.\n\
-\n\
-@item @qcode{\"noscal\"}, @qcode{\"P\"}\n\
-Permute only; do not scale.\n\
-@end table\n\
-\n\
-Algebraic eigenvalue balancing uses standard @sc{lapack} routines.\n\
-\n\
-Generalized eigenvalue problem balancing uses Ward's algorithm\n\
-(SIAM Journal on Scientific and Statistical Computing, 1981).\n\
-@end deftypefn")
-{
-  octave_value_list retval;
+       doc: /* -*- texinfo -*-
+@deftypefn  {} {@var{AA} =} balance (@var{A})
+@deftypefnx {} {@var{AA} =} balance (@var{A}, @var{opt})
+@deftypefnx {} {[@var{DD}, @var{AA}] =} balance (@var{A}, @var{opt})
+@deftypefnx {} {[@var{D}, @var{P}, @var{AA}] =} balance (@var{A}, @var{opt})
+@deftypefnx {} {[@var{CC}, @var{DD}, @var{AA}, @var{BB}] =} balance (@var{A}, @var{B}, @var{opt})
 
+Balance the matrix @var{A} to reduce numerical errors in future
+calculations.
+
+Compute @code{@var{AA} = @var{DD} \ @var{A} * @var{DD}} in which @var{AA}
+is a matrix whose row and column norms are roughly equal in magnitude, and
+@code{@var{DD} = @var{P} * @var{D}}, in which @var{P} is a permutation
+matrix and @var{D} is a diagonal matrix of powers of two.  This allows the
+equilibration to be computed without round-off.  Results of eigenvalue
+calculation are typically improved by balancing first.
+
+If two output values are requested, @code{balance} returns
+the diagonal @var{D} and the permutation @var{P} separately as vectors.
+In this case, @code{@var{DD} = eye(n)(:,@var{P}) * diag (@var{D})}, where
+@math{n} is the matrix size.
+
+If four output values are requested, compute @code{@var{AA} =
+@var{CC}*@var{A}*@var{DD}} and @code{@var{BB} = @var{CC}*@var{B}*@var{DD}},
+in which @var{AA} and @var{BB} have nonzero elements of approximately the
+same magnitude and @var{CC} and @var{DD} are permuted diagonal matrices as
+in @var{DD} for the algebraic eigenvalue problem.
+
+The eigenvalue balancing option @var{opt} may be one of:
+
+@table @asis
+@item @qcode{"noperm"}, @qcode{"S"}
+Scale only; do not permute.
+
+@item @qcode{"noscal"}, @qcode{"P"}
+Permute only; do not scale.
+@end table
+
+Algebraic eigenvalue balancing uses standard @sc{lapack} routines.
+
+Generalized eigenvalue problem balancing uses Ward's algorithm
+(SIAM Journal on Scientific and Statistical Computing, 1981).
+@end deftypefn */)
+{
   int nargin = args.length ();
 
-  if (nargin < 1 || nargin > 3 || nargout < 0 || nargout > 4)
-    {
-      print_usage ();
-      return retval;
-    }
+  if (nargin < 1 || nargin > 3 || nargout < 0)
+    print_usage ();
+
+  octave_value_list retval;
 
   // determine if it's AEP or GEP
   bool AEPcase = nargin == 1 || args(1).is_string ();
@@ -105,10 +103,7 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
   octave_idx_type nn = args(0).rows ();
 
   if (nn != args(0).columns ())
-    {
-      gripe_square_matrix_required ("balance");
-      return retval;
-    }
+    err_square_matrix_required ("balance", "A");
 
   bool isfloat = args(0).is_single_type ()
                  || (! AEPcase && args(1).is_single_type ());
@@ -137,14 +132,12 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
         aa = args(0).matrix_value ();
     }
 
-  if (error_state)
-    return retval;
-
   // Treat AEP/GEP cases.
   if (AEPcase)
     {
       // Algebraic eigenvalue problem.
-      bool noperm = false, noscal = false;
+      bool noperm = false;
+      bool noscal = false;
       if (nargin > 1)
         {
           std::string a1s = args(1).string_value ();
@@ -157,79 +150,62 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
         {
           if (complex_case)
             {
-              FloatComplexAEPBALANCE result (fcaa, noperm, noscal);
+              octave::math::aepbalance<FloatComplexMatrix> result (fcaa, noperm, noscal);
 
               if (nargout == 0 || nargout == 1)
-                retval(0) = result.balanced_matrix ();
+                retval = ovl (result.balanced_matrix ());
               else if (nargout == 2)
-                {
-                  retval(1) = result.balanced_matrix ();
-                  retval(0) = result.balancing_matrix ();
-                }
+                retval = ovl (result.balancing_matrix (),
+                              result.balanced_matrix ());
               else
-                {
-                  retval(2) = result.balanced_matrix ();
-                  retval(1) = result.permuting_vector ();
-                  retval(0) = result.scaling_vector ();
-                }
-
+                retval = ovl (result.scaling_vector (),
+                              result.permuting_vector (),
+                              result.balanced_matrix ());
             }
           else
             {
-              FloatAEPBALANCE result (faa, noperm, noscal);
+              octave::math::aepbalance<FloatMatrix> result (faa, noperm, noscal);
 
               if (nargout == 0 || nargout == 1)
-                retval(0) = result.balanced_matrix ();
+                retval = ovl (result.balanced_matrix ());
               else if (nargout == 2)
-                {
-                  retval(1) = result.balanced_matrix ();
-                  retval(0) = result.balancing_matrix ();
-                }
+                retval = ovl (result.balancing_matrix (),
+                              result.balanced_matrix ());
               else
-                {
-                  retval(2) = result.balanced_matrix ();
-                  retval(1) = result.permuting_vector ();
-                  retval(0) = result.scaling_vector ();
-                }
+                retval = ovl (result.scaling_vector (),
+                              result.permuting_vector (),
+                              result.balanced_matrix ());
             }
         }
       else
         {
           if (complex_case)
             {
-              ComplexAEPBALANCE result (caa, noperm, noscal);
+              octave::math::aepbalance<ComplexMatrix> result (caa, noperm, noscal);
 
               if (nargout == 0 || nargout == 1)
-                retval(0) = result.balanced_matrix ();
+                retval = ovl (result.balanced_matrix ());
               else if (nargout == 2)
-                {
-                  retval(1) = result.balanced_matrix ();
-                  retval(0) = result.balancing_matrix ();
-                }
+                retval = ovl (result.balancing_matrix (),
+                              result.balanced_matrix ());
               else
-                {
-                  retval(2) = result.balanced_matrix ();
-                  retval(1) = result.permuting_vector ();
-                  retval(0) = result.scaling_vector ();
-                }
+                retval = ovl (result.scaling_vector (),
+                              result.permuting_vector (),
+                              result.balanced_matrix ());
             }
           else
             {
-              AEPBALANCE result (aa, noperm, noscal);
+              octave::math::aepbalance<Matrix> result (aa, noperm, noscal);
 
               if (nargout == 0 || nargout == 1)
-                retval(0) = result.balanced_matrix ();
+                retval = ovl (result.balanced_matrix ());
               else if (nargout == 2)
-                {
-                  retval(1) = result.balanced_matrix ();
-                  retval(0) = result.balancing_matrix ();
-                }
+                retval = ovl (result.balancing_matrix (),
+                              result.balanced_matrix ());
               else
-                {
-                  retval(2) = result.balanced_matrix ();
-                  retval(1) = result.permuting_vector ();
-                  retval(0) = result.scaling_vector ();
-                }
+                retval = ovl (result.scaling_vector (),
+                              result.permuting_vector (),
+                              result.balanced_matrix ());
             }
         }
     }
@@ -242,19 +218,11 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
       // Generalized eigenvalue problem.
       if (nargin == 2)
         bal_job = "B";
-      else if (args(2).is_string ())
-        bal_job = args(2).string_value ();
       else
-        {
-          error ("balance: OPT argument must be a string");
-          return retval;
-        }
+        bal_job = args(2).xstring_value ("balance: OPT argument must be a string");
 
       if ((nn != args(1).columns ()) || (nn != args(1).rows ()))
-        {
-          gripe_nonconformant ();
-          return retval;
-        }
+        err_nonconformant ();
 
       Matrix bb;
       ComplexMatrix cbb;
@@ -281,7 +249,7 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
         {
           if (complex_case)
             {
-              FloatComplexGEPBALANCE result (fcaa, fcbb, bal_job);
+              octave::math::gepbalance<FloatComplexMatrix> result (fcaa, fcbb, bal_job);
 
               switch (nargout)
                 {
@@ -306,7 +274,7 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
             }
           else
             {
-              FloatGEPBALANCE result (faa, fbb, bal_job);
+              octave::math::gepbalance<FloatMatrix> result (faa, fbb, bal_job);
 
               switch (nargout)
                 {
@@ -334,7 +302,7 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
         {
           if (complex_case)
             {
-              ComplexGEPBALANCE result (caa, cbb, bal_job);
+              octave::math::gepbalance<ComplexMatrix> result (caa, cbb, bal_job);
 
               switch (nargout)
                 {
@@ -359,7 +327,7 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
             }
           else
             {
-              GEPBALANCE result (aa, bb, bal_job);
+              octave::math::gepbalance<Matrix> result (aa, bb, bal_job);
 
               switch (nargout)
                 {
@@ -387,3 +355,4 @@ Generalized eigenvalue problem balancing uses Ward's algorithm\n\
 
   return retval;
 }
+
