@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000-2013 John W. Eaton
+Copyright (C) 2000-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,8 +20,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include "lo-utils.h"
@@ -43,3 +43,4 @@ octave_comment_list::dup (void) const
 
   return new_cl;
 }
+
