@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2003-2012 John W. Eaton
+Copyright (C) 2003-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,9 +20,11 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#if !defined (octave_ls_mat_ascii_h)
+#if ! defined (octave_ls_mat_ascii_h)
 #define octave_ls_mat_ascii_h 1
 
+#include "octave-config.h"
+
 extern std::string
 read_mat_ascii_data (std::istream& is, const std::string& filename,
                      octave_value& tc);
@@ -31,6 +33,8 @@ extern bool
 save_mat_ascii_data (std::ostream& os, const octave_value& val_arg,
                      int precision, bool tabs = false);
 
-extern bool looks_like_mat_ascii_file (std::istream& is, const std::string& filename);
+extern bool looks_like_mat_ascii_file (std::istream& is,
+                                       const std::string& filename);
 
 #endif
+
