@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2015 John W. Eaton
+Copyright (C) 2009-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,13 +20,26 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#if !defined (octave_oct_hdf5_h)
-#define octave_hdf5_h 1
+#if ! defined (octave_oct_hdf5_h)
+#define octave_oct_hdf5_h 1
 
-#if defined (HAVE_HDF5_H)
+#include "octave-config.h"
 
-#include <hdf5.h>
+#if defined (HAVE_HDF5)
+
+#  if defined (HAVE_HDF5_H)
+#    include <hdf5.h>
+#  endif
+
+#  include "oct-hdf5-types.h"
+
+#  if defined (OCTAVE_ENABLE_64)
+#    define H5T_NATIVE_IDX H5T_NATIVE_INT64
+#  else
+#    define H5T_NATIVE_IDX H5T_NATIVE_INT
+#  endif
 
 #endif
 
 #endif
+
