@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2007-2015 Michael Weitzel
+Copyright (C) 2007-2016 Michael Weitzel
 
 This file is part of Octave.
 
@@ -50,14 +50,14 @@ Written by Michael Weitzel <michael.weitzel@@uni-siegen.de>
                            <weitzel@@ldknet.org>
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include "ov.h"
 #include "defun-dld.h"
 #include "error.h"
-#include "gripes.h"
+#include "errwarn.h"
 #include "utils.h"
 #include "oct-locbuf.h"
 
@@ -79,7 +79,7 @@ struct CMK_Node
 
 // A simple queue.
 // Queues Q have a fixed maximum size N (rows,cols of the matrix) and are
-// stored in an array. qh and qt point to queue head and tail.
+// stored in an array.  qh and qt point to queue head and tail.
 
 // Enqueue operation (adds a node "o" at the tail)
 
@@ -112,7 +112,7 @@ Q_deq (CMK_Node * Q, octave_idx_type N, octave_idx_type& qh)
 // the parent of entry i
 #define PARENT(i)       (((i) - 1) >> 1)        // = floor(((i)-1)/2)
 
-// Builds a min-heap (the root contains the smallest element). A is an array
+// Builds a min-heap (the root contains the smallest element).  A is an array
 // with the graph's nodes, i is a starting position, size is the length of A.
 
 static void
@@ -143,7 +143,7 @@ H_heapify_min (CMK_Node *A, octave_idx_type i, octave_idx_type size)
     }
 }
 
-// Heap operation insert. Running time is O(log(n))
+// Heap operation insert.  Running time is O(log(n))
 
 static void
 H_insert (CMK_Node *H, octave_idx_type& h, const CMK_Node& o)
@@ -169,7 +169,7 @@ H_insert (CMK_Node *H, octave_idx_type& h, const CMK_Node& o)
   while (i > 0);
 }
 
-// Heap operation remove-min. Removes the smalles element in O(1) and
+// Heap operation remove-min.  Removes the smalles element in O(1) and
 // reorganizes the heap optionally in O(log(n))
 
 inline static CMK_Node
@@ -185,7 +185,7 @@ H_remove_min (CMK_Node *H, octave_idx_type& h, int reorg/*=1*/)
 // Predicate (heap empty)
 #define H_empty(H, h)   ((h) == 0)
 
-// Helper function for the Cuthill-McKee algorithm. Tries to determine a
+// Helper function for the Cuthill-McKee algorithm.  Tries to determine a
 // pseudo-peripheral node of the graph as starting node.
 
 static octave_idx_type
@@ -322,8 +322,8 @@ find_starting_node (octave_idx_type N, const octave_idx_type *ridx,
   return x.id;
 }
 
-// Calculates the node's degrees. This means counting the nonzero elements
-// in the symmetric matrix' rows. This works for non-symmetric matrices
+// Calculates the node's degrees.  This means counting the nonzero elements
+// in the symmetric matrix' rows.  This works for non-symmetric matrices
 // as well.
 
 static octave_idx_type
@@ -412,39 +412,33 @@ transpose (octave_idx_type N, const octave_idx_type *ridx,
 
 // An implementation of the Cuthill-McKee algorithm.
 DEFUN_DLD (symrcm, args, ,
-           "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} {@var{p} =} symrcm (@var{S})\n\
-Return the symmetric reverse @nospell{Cuthill-McKee} permutation of @var{S}.\n\
-\n\
-@var{p} is a permutation vector such that\n\
-@code{@var{S}(@var{p}, @var{p})} tends to have its diagonal elements closer\n\
-to the diagonal than @var{S}.  This is a good preordering for LU or\n\
-Cholesky@tie{}factorization of matrices that come from ``long, skinny''\n\
-problems.  It works for both symmetric and asymmetric @var{S}.\n\
-\n\
-The algorithm represents a heuristic approach to the NP-complete bandwidth\n\
-minimization problem.  The implementation is based in the descriptions found\n\
-in\n\
-\n\
-@nospell{E. Cuthill, J. McKee}. @cite{Reducing the Bandwidth of Sparse\n\
-Symmetric Matrices}. Proceedings of the 24th ACM National Conference,\n\
-157--172 1969, Brandon Press, New Jersey.\n\
-\n\
-@nospell{A. George, J.W.H. Liu}. @cite{Computer Solution of Large Sparse\n\
-Positive Definite Systems}, Prentice Hall Series in Computational\n\
-Mathematics, ISBN 0-13-165274-5, 1981.\n\
-\n\
-@seealso{colperm, colamd, symamd}\n\
-@end deftypefn")
-{
-  octave_value retval;
-  int nargin = args.length ();
+           doc: /* -*- texinfo -*-
+@deftypefn {} {@var{p} =} symrcm (@var{S})
+Return the symmetric reverse @nospell{Cuthill-McKee} permutation of @var{S}.
 
-  if (nargin != 1)
-    {
-      print_usage ();
-      return retval;
-    }
+@var{p} is a permutation vector such that
+@code{@var{S}(@var{p}, @var{p})} tends to have its diagonal elements closer
+to the diagonal than @var{S}.  This is a good preordering for LU or
+Cholesky@tie{}factorization of matrices that come from ``long, skinny''
+problems.  It works for both symmetric and asymmetric @var{S}.
+
+The algorithm represents a heuristic approach to the NP-complete bandwidth
+minimization problem.  The implementation is based in the descriptions found
+in
+
+@nospell{E. Cuthill, J. McKee}. @cite{Reducing the Bandwidth of Sparse
+Symmetric Matrices}. Proceedings of the 24th ACM National Conference,
+157--172 1969, Brandon Press, New Jersey.
+
+@nospell{A. George, J.W.H. Liu}. @cite{Computer Solution of Large Sparse
+Positive Definite Systems}, Prentice Hall Series in Computational
+Mathematics, ISBN 0-13-165274-5, 1981.
+
+@seealso{colperm, colamd, symamd}
+@end deftypefn */)
+{
+  if (args.length () != 1)
+    print_usage ();
 
   octave_value arg = args(0);
 
@@ -469,20 +463,14 @@ Mathematics, ISBN 0-13-165274-5, 1981.\n\
       ridx = Ac.xridx ();
     }
 
-  if (error_state)
-    return retval;
-
   octave_idx_type nr = arg.rows ();
   octave_idx_type nc = arg.columns ();
 
   if (nr != nc)
-    {
-      gripe_square_matrix_required ("symrcm");
-      return retval;
-    }
+    err_square_matrix_required ("symrcm", "S");
 
   if (nr == 0 && nc == 0)
-    return octave_value (NDArray (dim_vector (1, 0)));
+    return ovl (NDArray (dim_vector (1, 0)));
 
   // sizes of the heaps
   octave_idx_type s = 0;
@@ -511,14 +499,15 @@ Mathematics, ISBN 0-13-165274-5, 1981.\n\
     {
       for (octave_idx_type i = 0; i < N; i++)
         P(i) = i;
-      return octave_value (P);
+
+      return ovl (P);
     }
 
-  // a heap for the a node's neighbors. The number of neighbors is
+  // a heap for the a node's neighbors.  The number of neighbors is
   // limited by the maximum degree max_deg:
   OCTAVE_LOCAL_BUFFER (CMK_Node, S, max_deg);
 
-  // a queue for the BFS. The array is always one element larger than
+  // a queue for the BFS.  The array is always one element larger than
   // the number of entries that are stored.
   OCTAVE_LOCAL_BUFFER (CMK_Node, Q, N+1);
 
@@ -526,7 +515,7 @@ Mathematics, ISBN 0-13-165274-5, 1981.\n\
   octave_idx_type c = -1;
 
   // upper bound for the bandwidth (=quality of solution)
-  // initialize the bandwidth of the graph with 0. B contains the
+  // initialize the bandwidth of the graph with 0.  B contains the
   // the maximum of the theoretical lower limits of the subgraphs
   // bandwidths.
   octave_idx_type B = 0;
@@ -549,7 +538,7 @@ Mathematics, ISBN 0-13-165274-5, 1981.\n\
       v.id = find_starting_node (N, ridx, cidx, ridx2, cidx2, D, i);
 
       // mark the node as visited and enqueue it (a starting node
-      // for the BFS). Since the node will be a root of a spanning
+      // for the BFS).  Since the node will be a root of a spanning
       // tree, its dist is 0.
       v.deg = D[v.id];
       v.dist = 0;
@@ -685,9 +674,9 @@ Mathematics, ISBN 0-13-165274-5, 1981.\n\
           if (Bsub < level_N)
             Bsub = level_N;
         }
-      // finish of BFS. If there are still unvisited nodes in the graph
-      // then it is split into CCs. The computed bandwidth is the maximum
-      // of all subgraphs. Update:
+      // finish of BFS.  If there are still unvisited nodes in the graph
+      // then it is split into CCs.  The computed bandwidth is the maximum
+      // of all subgraphs.  Update:
       if (Bsub > B)
         B = Bsub;
     }
@@ -700,5 +689,6 @@ Mathematics, ISBN 0-13-165274-5, 1981.\n\
     std::swap (P.elem (i), P.elem (j));
 
   // increment all indices, since Octave is not C
-  return octave_value (P+1);
+  return ovl (P+1);
 }
+
