@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2012 John W. Eaton
+Copyright (C) 1996-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,16 +20,17 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#if !defined (octave_function_h)
-#define octave_function_h 1
+#if ! defined (octave_ov_fcn_h)
+#define octave_ov_fcn_h 1
+
+#include "octave-config.h"
 
 #include <string>
 
 #include "oct-time.h"
 #include "str-vec.h"
 
-#include "oct-alloc.h"
-#include "oct-obj.h"
+#include "ovl.h"
 #include "ov-base.h"
 #include "ov-typeinfo.h"
 #include "symtab.h"
@@ -46,7 +47,8 @@ public:
 
   octave_function (void)
     : relative (false), locked (false), private_function (false),
-      xdispatch_class (), my_name (), my_dir_name (), doc () { }
+      xdispatch_class (), xpackage_name (), my_name (), my_dir_name (),
+      doc () { }
 
   ~octave_function (void) { }
 
@@ -59,34 +61,38 @@ public:
 
   virtual bool is_system_fcn_file (void) const { return false; }
 
-  virtual std::string fcn_file_name (void) const { return std::string (); }
+  virtual std::string fcn_file_name (void) const { return ""; }
 
-  virtual std::string src_file_name (void) const { return std::string (); }
+  virtual std::string src_file_name (void) const { return ""; }
 
   // The name to show in the profiler (also used as map-key).
   virtual std::string profiler_name (void) const { return name (); }
 
-  virtual std::string parent_fcn_name (void) const { return std::string (); }
+  virtual std::string parent_fcn_name (void) const { return ""; }
 
   virtual symbol_table::scope_id parent_fcn_scope (void) const { return -1; }
 
-  virtual void mark_fcn_file_up_to_date (const octave_time&) { }
+  virtual void mark_fcn_file_up_to_date (const octave::sys::time&) { }
 
   virtual symbol_table::scope_id scope (void) { return -1; }
 
-  virtual octave_time time_parsed (void) const
-    { return octave_time (static_cast<time_t> (0)); }
+  virtual octave::sys::time time_parsed (void) const
+  { return octave::sys::time (static_cast<time_t> (0)); }
 
-  virtual octave_time time_checked (void) const
-    { return octave_time (static_cast<time_t> (0)); }
+  virtual octave::sys::time time_checked (void) const
+  { return octave::sys::time (static_cast<time_t> (0)); }
 
   virtual bool is_subfunction (void) const { return false; }
 
-  virtual bool is_class_constructor (const std::string& = std::string ()) const
-    { return false; }
+  virtual bool is_class_constructor (const std::string& = "") const
+  { return false; }
 
-  virtual bool is_class_method (const std::string& = std::string ()) const
-    { return false; }
+  virtual bool
+  is_classdef_constructor (const std::string& = "") const
+  { return false; }
+
+  virtual bool is_class_method (const std::string& = "") const
+  { return false; }
 
   virtual bool takes_varargs (void) const { return false; }
 
@@ -96,8 +102,12 @@ public:
 
   std::string dispatch_class (void) const { return xdispatch_class; }
 
+  void stash_package_name (const std::string& pack) { xpackage_name = pack; }
+
+  std::string package_name (void) const { return xpackage_name; }
+
   virtual void
-  mark_as_private_function (const std::string& cname = std::string ())
+  mark_as_private_function (const std::string& cname = "")
   {
     private_function = true;
     xdispatch_class = cname;
@@ -106,11 +116,11 @@ public:
   bool is_private_function (void) const { return private_function; }
 
   bool is_private_function_of_class (const std::string& nm) const
-    { return private_function && xdispatch_class == nm; }
+  { return private_function && xdispatch_class == nm; }
 
   virtual bool
-  is_anonymous_function_of_class (const std::string& = std::string ()) const
-    { return false; }
+  is_anonymous_function_of_class (const std::string& = "") const
+  { return false; }
 
   std::string dir_name (void) const { return my_dir_name; }
 
@@ -152,6 +162,14 @@ public:
 
   std::string name (void) const { return my_name; }
 
+  std::string canonical_name (void) const
+  {
+    if (xpackage_name.empty ())
+      return my_name;
+    else
+      return xpackage_name + "." + my_name;
+  }
+
   void document (const std::string& ds) { doc = ds; }
 
   std::string doc_string (void) const { return doc; }
@@ -160,10 +178,13 @@ public:
 
   virtual void accept (tree_walker&) { }
 
+  virtual bool is_postfix_index_handled (char type) const
+  { return (type == '(' || type == '{'); }
+
 protected:
 
   octave_function (const std::string& nm,
-                   const std::string& ds = std::string ())
+                   const std::string& ds = "")
     : relative (false), locked (false), private_function (false),
       xdispatch_class (), my_name (nm), my_dir_name (), doc (ds) { }
 
@@ -181,6 +202,10 @@ protected:
   // to which the method belongs.
   std::string xdispatch_class;
 
+  // If this function is part of a package, this is the full name
+  // of the package to which the function belongs.
+  std::string xpackage_name;
+
   // The name of this function.
   std::string my_name;
 
@@ -199,7 +224,7 @@ private:
 
   octave_function& operator = (const octave_function& f);
 
-  DECLARE_OCTAVE_ALLOCATOR
 };
 
 #endif
+
