@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2004-2015 David Bateman
+Copyright (C) 2004-2016 David Bateman
 Copyright (C) 1998-2004 Andy Adler
 
 This file is part of Octave.
@@ -21,8 +21,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include <iostream>
@@ -36,7 +36,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "mxarray.h"
 #include "ov-base.h"
 #include "ov-scalar.h"
-#include "gripes.h"
+#include "errwarn.h"
 
 #include "oct-hdf5.h"
 #include "ls-hdf5.h"
@@ -48,8 +48,8 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "ov-bool-sparse.h"
 
-template class OCTINTERP_API octave_base_sparse<SparseMatrix>;
 
+template class OCTINTERP_API octave_base_sparse<SparseMatrix>;
 
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_sparse_matrix, "sparse matrix",
                                      "double");
@@ -61,9 +61,8 @@ octave_sparse_matrix::index_vector (bool /* require_integers */) const
     return idx_vector (array_value ());
   else
     {
-      std::string nm = type_name ();
-      error ("%s type invalid as index value", nm.c_str ());
-      return idx_vector ();
+      std::string nm = "<" + type_name () + ">";
+      octave::err_invalid_index (nm.c_str ());
     }
 }
 
@@ -96,42 +95,28 @@ octave_sparse_matrix::try_narrowing_conversion (void)
 double
 octave_sparse_matrix::double_value (bool) const
 {
-  double retval = lo_ieee_nan_value ();
+  if (is_empty ())
+    err_invalid_conversion ("real sparse matrix", "real scalar");
 
-  if (numel () > 0)
-    {
-      if (numel () > 1)
-        gripe_implicit_conversion ("Octave:array-to-scalar",
-                                   "real sparse matrix", "real scalar");
+  if (numel () > 1)
+    warn_implicit_conversion ("Octave:array-to-scalar",
+                              "real sparse matrix", "real scalar");
 
-      retval = matrix (0, 0);
-    }
-  else
-    gripe_invalid_conversion ("real sparse matrix", "real scalar");
-
-  return retval;
+  return matrix(0, 0);
 }
 
 Complex
 octave_sparse_matrix::complex_value (bool) const
 {
-  double tmp = lo_ieee_nan_value ();
-
-  Complex retval (tmp, tmp);
-
   // FIXME: maybe this should be a function, valid_as_scalar()
-  if (rows () > 0 && columns () > 0)
-    {
-      if (numel () > 1)
-        gripe_implicit_conversion ("Octave:array-to-scalar",
-                                   "real sparse matrix", "complex scalar");
+  if (rows () == 0 || columns () == 0)
+    err_invalid_conversion ("real sparse matrix", "complex scalar");
 
-      retval = matrix (0, 0);
-    }
-  else
-    gripe_invalid_conversion ("real sparse matrix", "complex scalar");
+  if (numel () > 1)
+    warn_implicit_conversion ("Octave:array-to-scalar",
+                              "real sparse matrix", "complex scalar");
 
-  return retval;
+  return Complex (matrix(0, 0), 0);
 }
 
 Matrix
@@ -146,9 +131,9 @@ octave_sparse_matrix::bool_array_value (bool warn) const
   NDArray m = matrix.matrix_value ();
 
   if (m.any_element_is_nan ())
-    gripe_nan_to_logical_conversion ();
-  else if (warn && m.any_element_not_one_or_zero ())
-    gripe_logical_conversion ();
+    octave::err_nan_to_logical_conversion ();
+  if (warn && m.any_element_not_one_or_zero ())
+    warn_logical_conversion ();
 
   return boolNDArray (m);
 }
@@ -189,9 +174,9 @@ SparseBoolMatrix
 octave_sparse_matrix::sparse_bool_matrix_value (bool warn) const
 {
   if (matrix.any_element_is_nan ())
-    gripe_nan_to_logical_conversion ();
-  else if (warn && matrix.any_element_not_one_or_zero ())
-    gripe_logical_conversion ();
+    octave::err_nan_to_logical_conversion ();
+  if (warn && matrix.any_element_not_one_or_zero ())
+    warn_logical_conversion ();
 
   return mx_el_ne (matrix, 0.0);
 }
@@ -224,32 +209,25 @@ octave_sparse_matrix::convert_to_str_internal (bool, bool, char type) const
 
             double d = matrix.data (i);
 
-            if (xisnan (d))
-              {
-                gripe_nan_to_character_conversion ();
-                return retval;
-              }
-            else
-              {
-                int ival = NINT (d);
+            if (octave::math::isnan (d))
+              octave::err_nan_to_character_conversion ();
 
-                if (ival < 0
-                    || ival > std::numeric_limits<unsigned char>::max ())
+            int ival = octave::math::nint (d);
+
+            if (ival < 0 || ival > std::numeric_limits<unsigned char>::max ())
+              {
+                // FIXME: is there something better we could do?
+
+                ival = 0;
+
+                if (! warned)
                   {
-                    // FIXME: is there something better we could do?
-
-                    ival = 0;
-
-                    if (! warned)
-                      {
-                        ::warning ("range error for conversion to character value");
-                        warned = true;
-                      }
+                    ::warning ("range error for conversion to character value");
+                    warned = true;
                   }
-
-                chm (matrix.ridx (i) + j * nr) =
-                  static_cast<char> (ival);
               }
+
+            chm(matrix.ridx (i) + j * nr) = static_cast<char> (ival);
           }
 
       retval = octave_value (chm, type);
@@ -258,18 +236,24 @@ octave_sparse_matrix::convert_to_str_internal (bool, bool, char type) const
   return retval;
 }
 
-bool
-octave_sparse_matrix::save_binary (std::ostream& os, bool&save_as_floats)
+octave_value
+octave_sparse_matrix::as_double (void) const
 {
-  dim_vector d = this->dims ();
-  if (d.length () < 1)
+  return this->matrix;
+}
+
+bool
+octave_sparse_matrix::save_binary (std::ostream& os, bool& save_as_floats)
+{
+  dim_vector dv = this->dims ();
+  if (dv.ndims () < 1)
     return false;
 
   // Ensure that additional memory is deallocated
   matrix.maybe_compress ();
 
-  int nr = d(0);
-  int nc = d(1);
+  int nr = dv(0);
+  int nc = dv(1);
   int nz = nnz ();
 
   int32_t itmp;
@@ -327,7 +311,7 @@ octave_sparse_matrix::save_binary (std::ostream& os, bool&save_as_floats)
 
 bool
 octave_sparse_matrix::load_binary (std::istream& is, bool swap,
-                                   oct_mach_info::float_format fmt)
+                                   octave::mach_info::float_format fmt)
 {
   int32_t nz, nc, nr, tmp;
   char ctmp;
@@ -339,10 +323,7 @@ octave_sparse_matrix::load_binary (std::istream& is, bool swap,
     swap_bytes<4> (&tmp);
 
   if (tmp != -2)
-    {
-      error ("load: only 2-D sparse matrices are supported");
-      return false;
-    }
+    error ("load: only 2-D sparse matrices are supported");
 
   if (! is.read (reinterpret_cast<char *> (&nr), 4))
     return false;
@@ -387,7 +368,7 @@ octave_sparse_matrix::load_binary (std::istream& is, bool swap,
 
   read_doubles (is, m.xdata (), static_cast<save_type> (ctmp), nz, swap, fmt);
 
-  if (error_state || ! is)
+  if (! is)
     return false;
 
   if (! m.indices_ok ())
@@ -414,9 +395,9 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
   // Ensure that additional memory is deallocated
   matrix.maybe_compress ();
 
-#if HAVE_HDF5_18
-  hid_t group_hid = H5Gcreate (loc_id, name, H5P_DEFAULT, H5P_DEFAULT,
-                               H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  hid_t group_hid = H5Gcreate (loc_id, name, octave_H5P_DEFAULT,
+                               octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   hid_t group_hid = H5Gcreate (loc_id, name, 0);
 #endif
@@ -435,12 +416,12 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
       H5Gclose (group_hid);
       return false;
     }
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (group_hid, "nr", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (group_hid, "nr", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT);
+                        octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -450,21 +431,21 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   tmp = m.rows ();
-  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-                     &tmp) >= 0;
+  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, &tmp) >= 0;
   H5Dclose (data_hid);
-  if (!retval)
+  if (! retval)
     {
       H5Sclose (space_hid);
       H5Gclose (group_hid);
       return false;
     }
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (group_hid, "nc", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (group_hid, "nc", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT);
+                        octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -474,22 +455,22 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   tmp = m.cols ();
-  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-                     &tmp) >= 0;
+  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, &tmp) >= 0;
   H5Dclose (data_hid);
-  if (!retval)
+  if (! retval)
     {
       H5Sclose (space_hid);
       H5Gclose (group_hid);
       return false;
     }
 
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (group_hid, "nz", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (group_hid, "nz", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT);
+                        octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -499,10 +480,10 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   tmp = m.nnz ();
-  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-                     &tmp) >= 0;
+  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, &tmp) >= 0;
   H5Dclose (data_hid);
-  if (!retval)
+  if (! retval)
     {
       H5Sclose (space_hid);
       H5Gclose (group_hid);
@@ -522,12 +503,12 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
       return false;
     }
 
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (group_hid, "cidx", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (group_hid, "cidx", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT);
+                        octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -537,10 +518,10 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   octave_idx_type * itmp = m.xcidx ();
-  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-                     itmp) >= 0;
+  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, itmp) >= 0;
   H5Dclose (data_hid);
-  if (!retval)
+  if (! retval)
     {
       H5Sclose (space_hid);
       H5Gclose (group_hid);
@@ -559,12 +540,12 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
       H5Gclose (group_hid);
       return false;
     }
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (group_hid, "ridx", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (group_hid, "ridx", H5T_NATIVE_IDX, space_hid,
-                        H5P_DEFAULT);
+                        octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -574,10 +555,10 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   itmp = m.xridx ();
-  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-                     itmp) >= 0;
+  retval = H5Dwrite (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, itmp) >= 0;
   H5Dclose (data_hid);
-  if (!retval)
+  if (! retval)
     {
       H5Sclose (space_hid);
       H5Gclose (group_hid);
@@ -596,7 +577,7 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
       else
         save_type_hid = H5T_NATIVE_FLOAT;
     }
-#if HAVE_HDF5_INT2FLOAT_CONVERSIONS
+#if defined (HAVE_HDF5_INT2FLOAT_CONVERSIONS)
   // hdf5 currently doesn't support float/integer conversions
   else
     {
@@ -606,14 +587,14 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
         save_type_hid
           = save_type_to_hdf5 (get_save_type (max_val, min_val));
     }
-#endif /* HAVE_HDF5_INT2FLOAT_CONVERSIONS */
+#endif
 
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (group_hid, "data", save_type_hid, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (group_hid, "data", save_type_hid, space_hid,
-                        H5P_DEFAULT);
+                        octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -623,14 +604,18 @@ octave_sparse_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   double * dtmp = m.xdata ();
-  retval = H5Dwrite (data_hid, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL,
-                     H5P_DEFAULT, dtmp) >= 0;
+  retval = H5Dwrite (data_hid, H5T_NATIVE_DOUBLE, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, dtmp) >= 0;
   H5Dclose (data_hid);
   H5Sclose (space_hid);
   H5Gclose (group_hid);
 
 #else
-  gripe_save ("hdf5");
+  octave_unused_parameter (loc_id);
+  octave_unused_parameter (name);
+  octave_unused_parameter (save_as_floats);
+
+  warn_save ("hdf5");
 #endif
 
   return retval;
@@ -654,15 +639,15 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
   if (empty)
     return (empty > 0);
 
-#if HAVE_HDF5_18
-  group_hid = H5Gopen (loc_id, name, H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  group_hid = H5Gopen (loc_id, name, octave_H5P_DEFAULT);
 #else
   group_hid = H5Gopen (loc_id, name);
 #endif
   if (group_hid < 0) return false;
 
-#if HAVE_HDF5_18
-  data_hid = H5Dopen (group_hid, "nr", H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  data_hid = H5Dopen (group_hid, "nr", octave_H5P_DEFAULT);
 #else
   data_hid = H5Dopen (group_hid, "nr");
 #endif
@@ -676,8 +661,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
       return false;
     }
 
-  if (H5Dread (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL,
-               H5P_DEFAULT, &nr) < 0)
+  if (H5Dread (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, &nr) < 0)
     {
       H5Dclose (data_hid);
       H5Gclose (group_hid);
@@ -686,8 +671,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
 
   H5Dclose (data_hid);
 
-#if HAVE_HDF5_18
-  data_hid = H5Dopen (group_hid, "nc", H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  data_hid = H5Dopen (group_hid, "nc", octave_H5P_DEFAULT);
 #else
   data_hid = H5Dopen (group_hid, "nc");
 #endif
@@ -701,8 +686,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
       return false;
     }
 
-  if (H5Dread (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL,
-               H5P_DEFAULT, &nc) < 0)
+  if (H5Dread (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, &nc) < 0)
     {
       H5Dclose (data_hid);
       H5Gclose (group_hid);
@@ -711,8 +696,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
 
   H5Dclose (data_hid);
 
-#if HAVE_HDF5_18
-  data_hid = H5Dopen (group_hid, "nz", H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  data_hid = H5Dopen (group_hid, "nz", octave_H5P_DEFAULT);
 #else
   data_hid = H5Dopen (group_hid, "nz");
 #endif
@@ -726,8 +711,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
       return false;
     }
 
-  if (H5Dread (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL,
-               H5P_DEFAULT, &nz) < 0)
+  if (H5Dread (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, &nz) < 0)
     {
       H5Dclose (data_hid);
       H5Gclose (group_hid);
@@ -740,8 +725,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
                   static_cast<octave_idx_type> (nc),
                   static_cast<octave_idx_type> (nz));
 
-#if HAVE_HDF5_18
-  data_hid = H5Dopen (group_hid, "cidx", H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  data_hid = H5Dopen (group_hid, "cidx", octave_H5P_DEFAULT);
 #else
   data_hid = H5Dopen (group_hid, "cidx");
 #endif
@@ -771,8 +756,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
     }
 
   octave_idx_type *itmp = m.xcidx ();
-  if (H5Dread (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL,
-               H5P_DEFAULT, itmp) < 0)
+  if (H5Dread (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, itmp) < 0)
     {
       H5Sclose (space_hid);
       H5Dclose (data_hid);
@@ -783,8 +768,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
   H5Sclose (space_hid);
   H5Dclose (data_hid);
 
-#if HAVE_HDF5_18
-  data_hid = H5Dopen (group_hid, "ridx", H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  data_hid = H5Dopen (group_hid, "ridx", octave_H5P_DEFAULT);
 #else
   data_hid = H5Dopen (group_hid, "ridx");
 #endif
@@ -810,8 +795,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
     }
 
   itmp = m.xridx ();
-  if (H5Dread (data_hid, H5T_NATIVE_IDX, H5S_ALL, H5S_ALL,
-               H5P_DEFAULT, itmp) < 0)
+  if (H5Dread (data_hid, H5T_NATIVE_IDX, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, itmp) < 0)
     {
       H5Sclose (space_hid);
       H5Dclose (data_hid);
@@ -822,8 +807,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
   H5Sclose (space_hid);
   H5Dclose (data_hid);
 
-#if HAVE_HDF5_18
-  data_hid = H5Dopen (group_hid, "data", H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  data_hid = H5Dopen (group_hid, "data", octave_H5P_DEFAULT);
 #else
   data_hid = H5Dopen (group_hid, "data");
 #endif
@@ -850,8 +835,8 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
 
   double *dtmp = m.xdata ();
 
-  if (H5Dread (data_hid, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL,
-               H5P_DEFAULT, dtmp) >= 0
+  if (H5Dread (data_hid, H5T_NATIVE_DOUBLE, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, dtmp) >= 0
       && m.indices_ok ())
     {
       retval = true;
@@ -863,7 +848,10 @@ octave_sparse_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
   H5Gclose (group_hid);
 
 #else
-  gripe_load ("hdf5");
+  octave_unused_parameter (loc_id);
+  octave_unused_parameter (name);
+
+  warn_load ("hdf5");
 #endif
 
   return retval;
@@ -905,57 +893,57 @@ octave_sparse_matrix::map (unary_mapper_t umap) const
       return matrix;
 
     // Mappers handled specially.
-#define ARRAY_METHOD_MAPPER(UMAP, FCN) \
-    case umap_ ## UMAP: \
+#define ARRAY_METHOD_MAPPER(UMAP, FCN)        \
+    case umap_ ## UMAP:                       \
       return octave_value (matrix.FCN ())
 
-      ARRAY_METHOD_MAPPER (abs, abs);
+    ARRAY_METHOD_MAPPER (abs, abs);
 
-#define ARRAY_MAPPER(UMAP, TYPE, FCN) \
-    case umap_ ## UMAP: \
+#define ARRAY_MAPPER(UMAP, TYPE, FCN)                 \
+    case umap_ ## UMAP:                               \
       return octave_value (matrix.map<TYPE> (FCN))
 
-      ARRAY_MAPPER (acos, Complex, rc_acos);
-      ARRAY_MAPPER (acosh, Complex, rc_acosh);
-      ARRAY_MAPPER (angle, double, ::arg);
-      ARRAY_MAPPER (arg, double, ::arg);
-      ARRAY_MAPPER (asin, Complex, rc_asin);
-      ARRAY_MAPPER (asinh, double, ::asinh);
-      ARRAY_MAPPER (atan, double, ::atan);
-      ARRAY_MAPPER (atanh, Complex, rc_atanh);
-      ARRAY_MAPPER (erf, double, ::erf);
-      ARRAY_MAPPER (erfinv, double, ::erfinv);
-      ARRAY_MAPPER (erfcinv, double, ::erfcinv);
-      ARRAY_MAPPER (erfc, double, ::erfc);
-      ARRAY_MAPPER (erfcx, double, ::erfcx);
-      ARRAY_MAPPER (erfi, double, ::erfi);
-      ARRAY_MAPPER (dawson, double, ::dawson);
-      ARRAY_MAPPER (gamma, double, xgamma);
-      ARRAY_MAPPER (lgamma, Complex, rc_lgamma);
-      ARRAY_MAPPER (cbrt, double, ::cbrt);
-      ARRAY_MAPPER (ceil, double, ::ceil);
-      ARRAY_MAPPER (cos, double, ::cos);
-      ARRAY_MAPPER (cosh, double, ::cosh);
-      ARRAY_MAPPER (exp, double, ::exp);
-      ARRAY_MAPPER (expm1, double, ::expm1);
-      ARRAY_MAPPER (fix, double, ::fix);
-      ARRAY_MAPPER (floor, double, ::floor);
-      ARRAY_MAPPER (log, Complex, rc_log);
-      ARRAY_MAPPER (log2, Complex, rc_log2);
-      ARRAY_MAPPER (log10, Complex, rc_log10);
-      ARRAY_MAPPER (log1p, Complex, rc_log1p);
-      ARRAY_MAPPER (round, double, xround);
-      ARRAY_MAPPER (roundb, double, xroundb);
-      ARRAY_MAPPER (signum, double, ::signum);
-      ARRAY_MAPPER (sin, double, ::sin);
-      ARRAY_MAPPER (sinh, double, ::sinh);
-      ARRAY_MAPPER (sqrt, Complex, rc_sqrt);
-      ARRAY_MAPPER (tan, double, ::tan);
-      ARRAY_MAPPER (tanh, double, ::tanh);
-      ARRAY_MAPPER (isnan, bool, xisnan);
-      ARRAY_MAPPER (isna, bool, octave_is_NA);
-      ARRAY_MAPPER (isinf, bool, xisinf);
-      ARRAY_MAPPER (finite, bool, xfinite);
+    ARRAY_MAPPER (acos, Complex, octave::math::rc_acos);
+    ARRAY_MAPPER (acosh, Complex, octave::math::rc_acosh);
+    ARRAY_MAPPER (angle, double, octave::math::arg);
+    ARRAY_MAPPER (arg, double,octave::math ::arg);
+    ARRAY_MAPPER (asin, Complex, octave::math::rc_asin);
+    ARRAY_MAPPER (asinh, double, octave::math::asinh);
+    ARRAY_MAPPER (atan, double, ::atan);
+    ARRAY_MAPPER (atanh, Complex, octave::math::rc_atanh);
+    ARRAY_MAPPER (erf, double, octave::math::erf);
+    ARRAY_MAPPER (erfinv, double, octave::math::erfinv);
+    ARRAY_MAPPER (erfcinv, double, octave::math::erfcinv);
+    ARRAY_MAPPER (erfc, double, octave::math::erfc);
+    ARRAY_MAPPER (erfcx, double, octave::math::erfcx);
+    ARRAY_MAPPER (erfi, double, octave::math::erfi);
+    ARRAY_MAPPER (dawson, double, octave::math::dawson);
+    ARRAY_MAPPER (gamma, double, octave::math::gamma);
+    ARRAY_MAPPER (lgamma, Complex, octave::math::rc_lgamma);
+    ARRAY_MAPPER (cbrt, double, octave::math::cbrt);
+    ARRAY_MAPPER (ceil, double, ::ceil);
+    ARRAY_MAPPER (cos, double, ::cos);
+    ARRAY_MAPPER (cosh, double, ::cosh);
+    ARRAY_MAPPER (exp, double, ::exp);
+    ARRAY_MAPPER (expm1, double, octave::math::expm1);
+    ARRAY_MAPPER (fix, double, octave::math::fix);
+    ARRAY_MAPPER (floor, double, ::floor);
+    ARRAY_MAPPER (log, Complex, octave::math::rc_log);
+    ARRAY_MAPPER (log2, Complex, octave::math::rc_log2);
+    ARRAY_MAPPER (log10, Complex, octave::math::rc_log10);
+    ARRAY_MAPPER (log1p, Complex, octave::math::rc_log1p);
+    ARRAY_MAPPER (round, double, octave::math::round);
+    ARRAY_MAPPER (roundb, double, octave::math::roundb);
+    ARRAY_MAPPER (signum, double, octave::math::signum);
+    ARRAY_MAPPER (sin, double, ::sin);
+    ARRAY_MAPPER (sinh, double, ::sinh);
+    ARRAY_MAPPER (sqrt, Complex, octave::math::rc_sqrt);
+    ARRAY_MAPPER (tan, double, ::tan);
+    ARRAY_MAPPER (tanh, double, ::tanh);
+    ARRAY_MAPPER (isnan, bool, octave::math::isnan);
+    ARRAY_MAPPER (isna, bool, octave::math::is_NA);
+    ARRAY_MAPPER (isinf, bool, octave::math::isinf);
+    ARRAY_MAPPER (isfinite, bool, octave::math::finite);
 
     default: // Attempt to go via dense matrix.
       return octave_base_sparse<SparseMatrix>::map (umap);
