@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2013 Jason Riedy
+Copyright (C) 2009-2016 Jason Riedy
 
 This file is part of Octave.
 
@@ -20,67 +20,25 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
-#include "gripes.h"
-#include "oct-obj.h"
+#include "errwarn.h"
+#include "ovl.h"
 #include "ov.h"
 #include "ov-typeinfo.h"
 #include "ops.h"
 
 #include "ov-perm.h"
 #include "ov-re-sparse.h"
-#include "ov-bool-sparse.h"
-
-// Unary permutation ops, some cast to sparse
-
-//Avoid casting to a full matrix
-DEFUNOP_OP (uplus, perm_matrix, /* no-op */)
-
-// Not calling standard CAST_UNOP_ARG for these next two because a
-// dynamic_cast would fail.
-DEFUNOP (not, perm_matrix)
-{
-  // Obviously negation of a permutation matrix destroys sparsity
-  return octave_value ( ! a.bool_array_value ());
-}
-
-DEFUNOP (uminus, perm_matrix)
-{
-  return octave_value ( - a.sparse_matrix_value ());
-}
-
-// Most other logical operations cast to SparseBoolMatrix
-DEFBINOP (eq_pm, perm_matrix, perm_matrix)
-{
-  CAST_BINOP_ARGS (const octave_perm_matrix&, const octave_perm_matrix&);
-  return v1.sparse_bool_matrix_value () == v2.sparse_bool_matrix_value ();
-}
-DEFBINOP (ne_pm, perm_matrix, perm_matrix)
-{
-  CAST_BINOP_ARGS (const octave_perm_matrix&, const octave_perm_matrix&);
-  return v1.sparse_bool_matrix_value () != v2.sparse_bool_matrix_value ();
-}
-DEFBINOP (el_and_pm, perm_matrix, perm_matrix)
-{
-  CAST_BINOP_ARGS (const octave_perm_matrix&, const octave_perm_matrix&);
-  return mx_el_and(v1.sparse_bool_matrix_value (),
-                   v2.sparse_bool_matrix_value ());
-}
-DEFBINOP (el_or_pm,  perm_matrix, perm_matrix)
-{
-  CAST_BINOP_ARGS (const octave_perm_matrix&, const octave_perm_matrix&);
-  return mx_el_or(v1.sparse_bool_matrix_value (),
-                  v2.sparse_bool_matrix_value ());
-}
 
 // permutation matrix by sparse matrix ops
 
 DEFBINOP (mul_pm_sm, perm_matrix, sparse_matrix)
 {
-  CAST_BINOP_ARGS (const octave_perm_matrix&, const octave_sparse_matrix&);
+  const octave_perm_matrix& v1 = dynamic_cast<const octave_perm_matrix&> (a1);
+  const octave_sparse_matrix& v2 = dynamic_cast<const octave_sparse_matrix&> (a2);
 
   if (v2.rows () == 1 && v2.columns () == 1)
     {
@@ -96,7 +54,8 @@ DEFBINOP (mul_pm_sm, perm_matrix, sparse_matrix)
 
 DEFBINOP (ldiv_pm_sm, perm_matrix, sparse_matrix)
 {
-  CAST_BINOP_ARGS (const octave_perm_matrix&, const octave_sparse_matrix&);
+  const octave_perm_matrix& v1 = dynamic_cast<const octave_perm_matrix&> (a1);
+  const octave_sparse_matrix& v2 = dynamic_cast<const octave_sparse_matrix&> (a2);
 
   return v1.perm_matrix_value ().inverse () * v2.sparse_matrix_value ();
 }
@@ -105,7 +64,8 @@ DEFBINOP (ldiv_pm_sm, perm_matrix, sparse_matrix)
 
 DEFBINOP (mul_sm_pm, sparse_matrix, perm_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_perm_matrix&);
+  const octave_sparse_matrix& v1 = dynamic_cast<const octave_sparse_matrix&> (a1);
+  const octave_perm_matrix& v2 = dynamic_cast<const octave_perm_matrix&> (a2);
 
   if (v1.rows () == 1 && v1.columns () == 1)
     {
@@ -121,7 +81,8 @@ DEFBINOP (mul_sm_pm, sparse_matrix, perm_matrix)
 
 DEFBINOP (div_sm_pm, sparse_matrix, perm_matrix)
 {
-  CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_perm_matrix&);
+  const octave_sparse_matrix& v1 = dynamic_cast<const octave_sparse_matrix&> (a1);
+  const octave_perm_matrix& v2 = dynamic_cast<const octave_perm_matrix&> (a2);
 
   return v1.sparse_matrix_value () * v2.perm_matrix_value ().inverse ();
 }
@@ -129,11 +90,6 @@ DEFBINOP (div_sm_pm, sparse_matrix, perm_matrix)
 void
 install_pm_sm_ops (void)
 {
-  INSTALL_UNOP (op_not, octave_perm_matrix, not);
-  INSTALL_UNOP (op_uplus, octave_perm_matrix, uplus);
-  INSTALL_UNOP (op_uminus, octave_perm_matrix, uminus);
-
-
   INSTALL_BINOP (op_mul, octave_perm_matrix, octave_sparse_matrix,
                  mul_pm_sm);
   INSTALL_BINOP (op_ldiv, octave_perm_matrix, octave_sparse_matrix,
@@ -142,9 +98,5 @@ install_pm_sm_ops (void)
                  mul_sm_pm);
   INSTALL_BINOP (op_div, octave_sparse_matrix, octave_perm_matrix,
                  div_sm_pm);
-
-  INSTALL_BINOP (op_eq, octave_perm_matrix, octave_perm_matrix, eq_pm);
-  INSTALL_BINOP (op_ne, octave_perm_matrix, octave_perm_matrix, ne_pm);
-  INSTALL_BINOP (op_el_and, octave_perm_matrix, octave_perm_matrix, el_and_pm);
-  INSTALL_BINOP (op_el_or,  octave_perm_matrix, octave_perm_matrix, el_or_pm);
 }
+
