@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2012 John W. Eaton
+Copyright (C) 1996-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,8 +20,10 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#if !defined (octave_tree_expr_h)
-#define octave_tree_expr_h 1
+#if ! defined (octave_pt_exp_h)
+#define octave_pt_exp_h 1
+
+#include "octave-config.h"
 
 #include <string>
 #include <list>
@@ -40,8 +42,8 @@ tree_expression : public tree
 public:
 
   tree_expression (int l = -1, int c = -1)
-    : tree (l, c), num_parens (0), postfix_indexed (false),
-      print_flag (false) { }
+    : tree (l, c), num_parens (0), postfix_index_type ('\0'),
+      for_cmd_expr (false), print_flag (false) { }
 
   virtual ~tree_expression (void) { }
 
@@ -80,18 +82,20 @@ public:
 
   virtual octave_value_list rvalue (int nargout);
 
-  virtual octave_value_list rvalue (int nargout,
-                                    const std::list<octave_lvalue> *lvalue_list);
+  virtual octave_value_list
+  rvalue (int nargout, const std::list<octave_lvalue> *lvalue_list);
 
   virtual octave_lvalue lvalue (void);
 
   int paren_count (void) const { return num_parens; }
 
-  bool is_postfix_indexed (void) const { return postfix_indexed; }
+  bool is_postfix_indexed (void) const { return (postfix_index_type != '\0'); }
+
+  char postfix_index (void) const { return postfix_index_type; }
 
   // Check if the result of the expression should be printed.
   // Should normally be used in conjunction with
-  // tree_evaluator::statement_printing_enabled.
+  // octave::tree_evaluator::statement_printing_enabled.
   bool print_result (void) const { return print_flag; }
 
   virtual std::string oper (void) const { return "<unknown>"; }
@@ -100,32 +104,36 @@ public:
 
   virtual std::string original_text (void) const;
 
-  virtual void mark_braindead_shortcircuit (const std::string&) { }
+  virtual void mark_braindead_shortcircuit (void) { }
+
+  void mark_as_for_cmd_expr (void) { for_cmd_expr = true; }
+
+  bool is_for_cmd_expr (void) const { return for_cmd_expr; }
 
   tree_expression *mark_in_parens (void)
-    {
-      num_parens++;
-      return this;
-    }
+  {
+    num_parens++;
+    return this;
+  }
 
-  tree_expression *mark_postfix_indexed (void)
-    {
-      postfix_indexed = true;
-      return this;
-    }
+  tree_expression *set_postfix_index (char type)
+  {
+    postfix_index_type = type;
+    return this;
+  }
 
   tree_expression *set_print_flag (bool print)
-    {
-      print_flag = print;
-      return this;
-    }
+  {
+    print_flag = print;
+    return this;
+  }
 
   virtual void copy_base (const tree_expression& e)
-    {
-      num_parens = e.num_parens;
-      postfix_indexed = e.postfix_indexed;
-      print_flag = e.print_flag;
-    }
+  {
+    num_parens = e.num_parens;
+    postfix_index_type = e.postfix_index_type;
+    print_flag = e.print_flag;
+  }
 
 protected:
 
@@ -137,9 +145,14 @@ protected:
   //                  ==> 0 for expression e2
   int num_parens;
 
-  // A flag that says whether this expression has an index associated
-  // with it.  See the code in tree_identifier::rvalue for the rationale.
-  bool postfix_indexed;
+  // The first index type associated with this expression.  This field
+  // is 0 (character '\0') if the expression has no associated index.
+  // See the code in tree_identifier::rvalue for the rationale.
+  char postfix_index_type;
+
+  // TRUE if this expression is the EXPR in for loop:
+  // FOR i = EXPR ... END
+  bool for_cmd_expr;
 
   // Print result of rvalue for this expression?
   bool print_flag;
@@ -154,3 +167,4 @@ private:
 };
 
 #endif
+
