@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2012 John W. Eaton
+Copyright (C) 1996-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,8 +20,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include <cctype>
@@ -329,7 +329,7 @@ tree_print_code::visit_octave_user_function (octave_user_function& fcn)
 
       cmd_list->accept (*this);
 
-      decrement_indent_level ();
+      // endfunction will decrement the indent level.
     }
 
   visit_octave_user_function_trailer (fcn);
@@ -600,7 +600,7 @@ tree_print_code::visit_index_expression (tree_index_expression& expr)
         case '.':
           {
             string_vector nm = *p_arg_names;
-            assert (nm.length () == 1);
+            assert (nm.numel () == 1);
             os << "." << nm(0);
           }
           break;
@@ -719,6 +719,9 @@ tree_print_code::visit_multi_assignment (tree_multi_assignment& expr)
 void
 tree_print_code::visit_no_op_command (tree_no_op_command& cmd)
 {
+  if (cmd.is_end_of_fcn_or_script () && curr_print_indent_level > 1)
+    decrement_indent_level ();
+
   indent ();
 
   os << cmd.original_command ();
@@ -748,6 +751,18 @@ tree_print_code::visit_fcn_handle (tree_fcn_handle& fh)
   print_parens (fh, ")");
 }
 
+void
+tree_print_code::visit_funcall (tree_funcall& fc)
+{
+  indent ();
+
+  print_parens (fc, "(");
+
+  fc.print_raw (os, true, print_original_text);
+
+  print_parens (fc, ")");
+}
+
 void
 tree_print_code::visit_parameter_list (tree_parameter_list& lst)
 {
@@ -861,13 +876,7 @@ tree_print_code::visit_statement (tree_statement& stmt)
     {
       cmd->accept (*this);
 
-      if (! stmt.print_result ())
-        {
-          os << ";";
-          newline (" ");
-        }
-      else
-        newline ();
+      newline ();
     }
   else
     {
@@ -1037,8 +1046,7 @@ tree_print_code::visit_try_catch_command (tree_try_catch_command& cmd)
 }
 
 void
-tree_print_code::visit_unwind_protect_command
-  (tree_unwind_protect_command& cmd)
+tree_print_code::visit_unwind_protect_command (tree_unwind_protect_command& cmd)
 {
   print_comment_list (cmd.leading_comment ());
 
@@ -1145,7 +1153,7 @@ tree_print_code::visit_do_until_command (tree_do_until_command& cmd)
 
   indent ();
 
-  os << "until";
+  os << "until ";
 
   tree_expression *expr = cmd.condition ();
 
@@ -1189,10 +1197,7 @@ tree_print_code::print_fcn_handle_body (tree_statement_list *b)
     }
 }
 
-// Each print_code() function should call this before printing
-// anything.
-//
-// This doesn't need to be fast, but isn't there a better way?
+// Each print_code() function should call this before printing anything.
 
 void
 tree_print_code::indent (void)
@@ -1203,8 +1208,7 @@ tree_print_code::indent (void)
     {
       os << prefix;
 
-      for (int i = 0; i < curr_print_indent_level; i++)
-        os << " ";
+      os << std::string (curr_print_indent_level, ' ');
 
       beginning_of_line = false;
     }
@@ -1219,6 +1223,9 @@ tree_print_code::newline (const char *alt_txt)
     os << alt_txt;
   else
     {
+      // Print prefix for blank lines.
+      indent ();
+
       os << "\n";
 
       beginning_of_line = true;
@@ -1259,7 +1266,7 @@ tree_print_code::print_comment_elt (const octave_comment_elt& elt)
   size_t i = 0;
 
   while (i < len && comment[i++] == '\n')
-    ; /* Skip leading new lines. */
+    ; // Skip leading new lines.
   i--;
 
   while (i < len)
@@ -1269,7 +1276,13 @@ tree_print_code::print_comment_elt (const octave_comment_elt& elt)
       if (c == '\n')
         {
           if (prev_char_was_newline)
-            os << "##";
+            {
+              printed_something = true;
+
+              indent ();
+
+              os << "##";
+            }
 
           newline ();
 
@@ -1327,3 +1340,4 @@ tree_print_code::print_indented_comment (octave_comment_list *comment_list)
 
   decrement_indent_level ();
 }
+
