@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2009-2015 Jaroslav Hajek
+Copyright (C) 2009-2016 Jaroslav Hajek
 Copyright (C) 2009 VZLU Prague
 
 This file is part of Octave.
@@ -21,9 +21,13 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#if !defined (octave_bsxfun_defs_h)
+#if ! defined (octave_bsxfun_defs_h)
 #define octave_bsxfun_defs_h 1
 
+// This file should not include config.h.  It is only included in other
+// C++ source files that should have included config.h before including
+// this file.
+
 #include <algorithm>
 #include <iostream>
 
@@ -33,7 +37,7 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "mx-inlines.cc"
 
-template <class R, class X, class Y>
+template <typename R, typename X, typename Y>
 Array<R>
 do_bsxfun_op (const Array<X>& x, const Array<Y>& y,
               void (*op_vv) (size_t, R *, const X *, const Y *),
@@ -56,12 +60,9 @@ do_bsxfun_op (const Array<X>& x, const Array<Y>& y,
       else if (yk == 1 || xk == yk)
         dvr(i) = xk;
       else
-        {
-          (*current_liboctave_error_handler)
-            ("bsxfun: nonconformant dimensions: %s and %s",
-             x.dims ().str ().c_str (), y.dims ().str ().c_str ());
-          break;
-        }
+        (*current_liboctave_error_handler)
+          ("bsxfun: nonconformant dimensions: %s and %s",
+           x.dims ().str ().c_str (), y.dims ().str ().c_str ());
     }
 
   Array<R> retval (dvr);
@@ -137,7 +138,7 @@ do_bsxfun_op (const Array<X>& x, const Array<Y>& y,
   return retval;
 }
 
-template <class R, class X>
+template <typename R, typename X>
 void
 do_inplace_bsxfun_op (Array<R>& r, const Array<X>& x,
                       void (*op_vv) (size_t, R *, const X *),
@@ -209,51 +210,52 @@ do_inplace_bsxfun_op (Array<R>& r, const Array<X>& x,
     }
 }
 
-#define BSXFUN_OP_DEF(OP, ARRAY) \
-ARRAY bsxfun_ ## OP (const ARRAY& x, const ARRAY& y)
+#define BSXFUN_OP_DEF(OP, ARRAY)                        \
+  ARRAY bsxfun_ ## OP (const ARRAY& x, const ARRAY& y)
 
-#define BSXFUN_OP2_DEF(OP, ARRAY, ARRAY1, ARRAY2) \
-ARRAY bsxfun_ ## OP (const ARRAY1& x, const ARRAY2& y)
+#define BSXFUN_OP2_DEF(OP, ARRAY, ARRAY1, ARRAY2)               \
+  ARRAY bsxfun_ ## OP (const ARRAY1& x, const ARRAY2& y)
 
-#define BSXFUN_REL_DEF(OP, ARRAY) \
-boolNDArray bsxfun_ ## OP (const ARRAY& x, const ARRAY& y)
+#define BSXFUN_REL_DEF(OP, ARRAY)                               \
+  boolNDArray bsxfun_ ## OP (const ARRAY& x, const ARRAY& y)
 
-#define BSXFUN_OP_DEF_MXLOOP(OP, ARRAY, LOOP) \
-  BSXFUN_OP_DEF(OP, ARRAY) \
+#define BSXFUN_OP_DEF_MXLOOP(OP, ARRAY, LOOP)                           \
+  BSXFUN_OP_DEF(OP, ARRAY)                                              \
   { return do_bsxfun_op<ARRAY::element_type, ARRAY::element_type, ARRAY::element_type> \
-    (x, y, LOOP, LOOP, LOOP); }
+      (x, y, LOOP, LOOP, LOOP); }
 
-#define BSXFUN_OP2_DEF_MXLOOP(OP, ARRAY, ARRAY1, ARRAY2, LOOP) \
-  BSXFUN_OP2_DEF(OP, ARRAY, ARRAY1, ARRAY2) \
+#define BSXFUN_OP2_DEF_MXLOOP(OP, ARRAY, ARRAY1, ARRAY2, LOOP)          \
+  BSXFUN_OP2_DEF(OP, ARRAY, ARRAY1, ARRAY2)                             \
   { return do_bsxfun_op<ARRAY::element_type, ARRAY1::element_type, ARRAY2::element_type> \
-    (x, y, LOOP, LOOP, LOOP); }
+      (x, y, LOOP, LOOP, LOOP); }
 
-#define BSXFUN_REL_DEF_MXLOOP(OP, ARRAY, LOOP) \
-  BSXFUN_REL_DEF(OP, ARRAY) \
+#define BSXFUN_REL_DEF_MXLOOP(OP, ARRAY, LOOP)                          \
+  BSXFUN_REL_DEF(OP, ARRAY)                                             \
   { return do_bsxfun_op<bool, ARRAY::element_type, ARRAY::element_type> \
-    (x, y, LOOP, LOOP, LOOP); }
+      (x, y, LOOP, LOOP, LOOP); }
 
-#define BSXFUN_STDOP_DEFS_MXLOOP(ARRAY) \
-  BSXFUN_OP_DEF_MXLOOP (add, ARRAY, mx_inline_add) \
-  BSXFUN_OP_DEF_MXLOOP (sub, ARRAY, mx_inline_sub) \
-  BSXFUN_OP_DEF_MXLOOP (mul, ARRAY, mx_inline_mul) \
-  BSXFUN_OP_DEF_MXLOOP (div, ARRAY, mx_inline_div) \
-  BSXFUN_OP_DEF_MXLOOP (min, ARRAY, mx_inline_xmin) \
+#define BSXFUN_STDOP_DEFS_MXLOOP(ARRAY)                 \
+  BSXFUN_OP_DEF_MXLOOP (add, ARRAY, mx_inline_add)      \
+  BSXFUN_OP_DEF_MXLOOP (sub, ARRAY, mx_inline_sub)      \
+  BSXFUN_OP_DEF_MXLOOP (mul, ARRAY, mx_inline_mul)      \
+  BSXFUN_OP_DEF_MXLOOP (div, ARRAY, mx_inline_div)      \
+  BSXFUN_OP_DEF_MXLOOP (min, ARRAY, mx_inline_xmin)     \
   BSXFUN_OP_DEF_MXLOOP (max, ARRAY, mx_inline_xmax)
 
-#define BSXFUN_STDREL_DEFS_MXLOOP(ARRAY) \
-  BSXFUN_REL_DEF_MXLOOP (eq, ARRAY, mx_inline_eq) \
-  BSXFUN_REL_DEF_MXLOOP (ne, ARRAY, mx_inline_ne) \
-  BSXFUN_REL_DEF_MXLOOP (lt, ARRAY, mx_inline_lt) \
-  BSXFUN_REL_DEF_MXLOOP (le, ARRAY, mx_inline_le) \
-  BSXFUN_REL_DEF_MXLOOP (gt, ARRAY, mx_inline_gt) \
+#define BSXFUN_STDREL_DEFS_MXLOOP(ARRAY)                \
+  BSXFUN_REL_DEF_MXLOOP (eq, ARRAY, mx_inline_eq)       \
+  BSXFUN_REL_DEF_MXLOOP (ne, ARRAY, mx_inline_ne)       \
+  BSXFUN_REL_DEF_MXLOOP (lt, ARRAY, mx_inline_lt)       \
+  BSXFUN_REL_DEF_MXLOOP (le, ARRAY, mx_inline_le)       \
+  BSXFUN_REL_DEF_MXLOOP (gt, ARRAY, mx_inline_gt)       \
   BSXFUN_REL_DEF_MXLOOP (ge, ARRAY, mx_inline_ge)
 
 //For bsxfun power with mixed integer/float types
-#define BSXFUN_POW_MIXED_MXLOOP(INT_TYPE)                              \
+#define BSXFUN_POW_MIXED_MXLOOP(INT_TYPE)                               \
   BSXFUN_OP2_DEF_MXLOOP (pow, INT_TYPE, INT_TYPE, NDArray, mx_inline_pow) \
-  BSXFUN_OP2_DEF_MXLOOP (pow, INT_TYPE, INT_TYPE, FloatNDArray, mx_inline_pow)\
+  BSXFUN_OP2_DEF_MXLOOP (pow, INT_TYPE, INT_TYPE, FloatNDArray, mx_inline_pow) \
   BSXFUN_OP2_DEF_MXLOOP (pow, INT_TYPE, NDArray, INT_TYPE,  mx_inline_pow) \
   BSXFUN_OP2_DEF_MXLOOP (pow, INT_TYPE, FloatNDArray, INT_TYPE, mx_inline_pow)
 
 #endif
+
