@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2012 John W. Eaton
+Copyright (C) 1996-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,8 +28,8 @@ function distributed in the GNU file utilities, copyright (C) 85, 88,
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include <iostream>
@@ -39,39 +39,6 @@ function distributed in the GNU file utilities, copyright (C) 85, 88,
 #include "lo-utils.h"
 #include "str-vec.h"
 
-// FIXME -- isn't there some STL trick that could be used to make this
-// work for all STL containers of std::string objects?
-
-string_vector::string_vector (const std::list<std::string>& lst)
-  : Array<std::string> ()
-{
-  size_t n = lst.size ();
-
-  resize (n);
-
-  octave_idx_type i = 0;
-
-  for (std::list<std::string>::const_iterator p = lst.begin ();
-       p != lst.end ();
-       p++)
-    elem (i++) = *p;
-}
-
-string_vector::string_vector (const std::set<std::string>& lst)
-  : Array<std::string> ()
-{
-  size_t n = lst.size ();
-
-  resize (n);
-
-  octave_idx_type i = 0;
-
-  for (std::set<std::string>::const_iterator p = lst.begin ();
-       p != lst.end ();
-       p++)
-    elem (i++) = *p;
-}
-
 // Create a string vector from a NULL terminated list of C strings.
 
 string_vector::string_vector (const char * const *s)
@@ -108,7 +75,7 @@ string_vector::sort (bool make_uniq)
 {
   // Don't use Array<std::string>::sort () to allow sorting in place.
   octave_sort<std::string> lsort;
-  lsort.sort (Array<std::string>::fortran_vec (), length ());
+  lsort.sort (Array<std::string>::fortran_vec (), numel ());
 
   if (make_uniq)
     uniq ();
@@ -118,7 +85,7 @@ string_vector::sort (bool make_uniq)
 string_vector&
 string_vector::uniq (void)
 {
-  octave_idx_type len = length ();
+  octave_idx_type len = numel ();
 
   if (len > 0)
     {
@@ -139,7 +106,7 @@ string_vector::uniq (void)
 string_vector&
 string_vector::append (const std::string& s)
 {
-  octave_idx_type len = length ();
+  octave_idx_type len = numel ();
 
   resize (len + 1);
 
@@ -151,8 +118,8 @@ string_vector::append (const std::string& s)
 string_vector&
 string_vector::append (const string_vector& sv)
 {
-  octave_idx_type len = length ();
-  octave_idx_type sv_len = sv.length ();
+  octave_idx_type len = numel ();
+  octave_idx_type sv_len = sv.numel ();
   octave_idx_type new_len = len + sv_len;
 
   resize (new_len);
@@ -168,7 +135,7 @@ string_vector::join (const std::string& sep) const
 {
   std::string retval;
 
-  octave_idx_type len = length ();
+  octave_idx_type len = numel ();
 
   if (len > 0)
     {
@@ -186,7 +153,7 @@ string_vector::join (const std::string& sep) const
 char **
 string_vector::c_str_vec (void) const
 {
-  octave_idx_type len = length ();
+  octave_idx_type len = numel ();
 
   char **retval = new char * [len + 1];
 
@@ -198,6 +165,19 @@ string_vector::c_str_vec (void) const
   return retval;
 }
 
+std::list<std::string>
+string_vector::std_list (void) const
+{
+  octave_idx_type len = numel ();
+
+  std::list<std::string> retval;
+
+  for (octave_idx_type i = 0; i < len; i++)
+    retval.push_back (elem (i));
+
+  return retval;
+}
+
 void
 string_vector::delete_c_str_vec (const char * const *v)
 {
@@ -218,7 +198,7 @@ string_vector::list_in_columns (std::ostream& os, int width,
   // Compute the maximum name length.
 
   octave_idx_type max_name_length = 0;
-  octave_idx_type total_names = length ();
+  octave_idx_type total_names = numel ();
 
   if (total_names == 0)
     {
@@ -242,7 +222,7 @@ string_vector::list_in_columns (std::ostream& os, int width,
   // Calculate the maximum number of columns that will fit.
 
   octave_idx_type line_length
-    = ((width <= 0 ? command_editor::terminal_cols () : width)
+    = ((width <= 0 ? octave::command_editor::terminal_cols () : width)
        - prefix.length ());
 
   octave_idx_type nc = line_length / max_name_length;
@@ -250,14 +230,10 @@ string_vector::list_in_columns (std::ostream& os, int width,
     nc = 1;
 
   // Calculate the number of rows that will be in each column except
-  // possibly  for a short column on the right.
+  // possibly for a short column on the right.
 
   octave_idx_type nr = total_names / nc + (total_names % nc != 0);
 
-  // Recalculate columns based on rows.
-
-  nc = total_names / nr + (total_names % nr != 0);
-
   octave_idx_type count;
   for (octave_idx_type row = 0; row < nr; row++)
     {
@@ -289,3 +265,4 @@ string_vector::list_in_columns (std::ostream& os, int width,
 
   return os;
 }
+
