@@ -1,4 +1,4 @@
-## Copyright (C) 2003-2013 John W. Eaton
+## Copyright (C) 2003-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} isstr (@var{a})
+## @deftypefn {} {} isstr (@var{a})
 ## This function has been deprecated.  Use ischar instead.
 ## @end deftypefn
 
