@@ -1,4 +1,4 @@
-## Copyright (C) 1993-2013 John W. Eaton
+## Copyright (C) 1993-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} int2str (@var{n})
+## @deftypefn {} {} int2str (@var{n})
 ## Convert an integer (or array of integers) to a string (or a character
 ## array).
 ##
@@ -41,6 +41,12 @@
 ##
 ## This function is not very flexible.  For better control over the
 ## results, use @code{sprintf} (@pxref{Formatted Output}).
+##
+## Programming Notes:
+##
+## Non-integers are rounded to integers before display.  Only the real part
+## of complex numbers is displayed.
+##
 ## @seealso{sprintf, num2str, mat2str}
 ## @end deftypefn
 
@@ -50,75 +56,53 @@ function retval = int2str (n)
 
   if (nargin != 1)
     print_usage ();
+  elseif (! (isnumeric (n) || islogical (n) || ischar (n)))
+    error ("int2str: N must be a numeric, logical, or character array");
   endif
 
-  if (isempty (n))
-    retval = '';
+  if (ischar (n))
+    retval = n;
+    return;
+  elseif (isempty (n))
+    retval = "";
     return;
   endif
 
   n = round (real (n));
-  sz = size (n);
+
+  ## Set up a suitable format string while ignoring Inf/NaN entries
+  nan_inf = ! isfinite (n(:));
+  ndgt = floor (log10 (max (abs (n(! nan_inf)))));
+  if (isempty (ndgt) || ndgt == -Inf)
+    ndgt = 0;  # All Inf or all zero array
+  endif
+
+  ndgt += 3;
+  if (any (nan_inf))
+    ndgt = max (ndgt, 5);
+  endif
+
+  ## FIXME: Integers should be masked to show only 16 significant digits
+  fmt = sprintf ("%%%d.0f", ndgt);
+
   nd = ndims (n);
-  nc = columns (n);
-  if (nc > 1)
-    idx = repmat ({':'}, nd, 1);
-    idx(2) = 1;
-    ifmt = get_fmt (n(idx{:}), 0);
-    idx(2) = 2:sz(2);
-    rfmt = get_fmt (n(idx{:}), 2);
-    fmt = [ifmt repmat(rfmt,1,nc-1) "\n"];
-  else
-    fmt = [get_fmt(n, 0) "\n"];
-  endif
-  tmp = sprintf (fmt, permute (n, [2, 1, 3 : nd]));
-  tmp(end) = "";
-  retval = char (ostrsplit (tmp, "\n"));
-
-endfunction
-
-function fmt = get_fmt (x, sep)
-
-  t = x(:);
-  t = t(t != 0);
-  if (isempty (t))
-    ## All zeros.
-    fmt = sprintf ("%%%dd", 1 + sep);
-  else
-    ## Maybe have some zeros.
-    nan_inf = ! isfinite (t);
-    if (any (nan_inf))
-      if (any (t(nan_inf) < 0))
-        min_fw = 4 + sep;
-      else
-        min_fw = 3 + sep;
-      endif
-    else
-      min_fw = 1 + sep;
-    endif
-    t = t(! nan_inf);
-    if (isempty (t))
-      ## Only zeros, Inf, and NaN.
-      fmt = sprintf ("%%%dd", min_fw);
-    else
-      ## Could have anything.
-      tfw = floor (log10 (double (abs (t)))) + 1 + sep;
-      fw = max (tfw);
-      if (any (t(tfw == fw) < 0))
-        fw++;
-      endif
-      fmt = sprintf ("%%%dd", max (fw, min_fw));
-    endif
-  endif
+  nc = columns (n) * (nd - 1);    # ND-arrays are expanded in columns
+  n  = permute (n, [2, 3:nd, 1]);
+  fmt = [repmat(fmt, 1, nc), "\n"];
+  strtmp = sprintf (fmt, n);
+  retval = strtrim (char (ostrsplit (strtmp, "\n", true)));
 
 endfunction
 
 
+%!assert (int2str (123), "123")
 %!assert (int2str (-123), "-123")
 %!assert (int2str (1.2), "1")
+%!assert (int2str (1.6), "2")
 %!assert (int2str ([1, 2, 3; 4, 5, 6]), ["1  2  3";"4  5  6"])
 %!assert (int2str ([]), "")
 
 %!error int2str ()
 %!error int2str (1, 2)
+%!error <N must be a numeric> int2str ({1})
 
