@@ -1,4 +1,4 @@
-## Copyright (C) 2004-2012 David Bateman
+## Copyright (C) 2004-2016 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,19 +17,21 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} rotdim (@var{x})
-## @deftypefnx {Function File} {} rotdim (@var{x}, @var{n})
-## @deftypefnx {Function File} {} rotdim (@var{x}, @var{n}, @var{plane})
+## @deftypefn  {} {} rotdim (@var{x})
+## @deftypefnx {} {} rotdim (@var{x}, @var{n})
+## @deftypefnx {} {} rotdim (@var{x}, @var{n}, @var{plane})
 ## Return a copy of @var{x} with the elements rotated counterclockwise in
 ## 90-degree increments.
-## The second argument @var{n} is optional, and specifies how many 90-degree
-## rotations are to be applied (the default value is 1).
-## The third argument is also optional and defines the plane of the
-## rotation.  If present, @var{plane} is a two element vector containing two
-## different valid dimensions of the matrix.  When @var{plane} is not given
-## the first two non-singleton dimensions are used.
 ##
-## Negative values of @var{n} rotate the matrix in a clockwise direction.
+## The second argument @var{n} is optional, and specifies how many 90-degree
+## rotations are to be applied (the default value is 1).  Negative values of
+## @var{n} rotate the matrix in a clockwise direction.
+##
+## The third argument is also optional and defines the plane of the rotation.
+## If present, @var{plane} is a two element vector containing two different
+## valid dimensions of the matrix.  When @var{plane} is not given the first two
+## non-singleton dimensions are used.
+##
 ## For example,
 ##
 ## @example
@@ -51,7 +53,7 @@
 ## rotdim ([1, 2; 3, 4], 7, [1, 2])
 ## @end group
 ## @end example
-## @seealso{rot90, flipud, fliplr, flipdim}
+## @seealso{rot90, fliplr, flipud, flip}
 ## @end deftypefn
 
 function y = rotdim (x, n, plane)
@@ -61,7 +63,7 @@ function y = rotdim (x, n, plane)
   endif
 
   if (nargin > 1 && ! isempty (n))
-    if (!isscalar (n) || !isreal (n) || fix (n) != n)
+    if (! isscalar (n) || ! isreal (n) || fix (n) != n)
       error ("rotdim: N must be a scalar integer");
     endif
   else
@@ -76,7 +78,7 @@ function y = rotdim (x, n, plane)
       plane = [];
       dim = 0;
       while (dim < nd)
-        dim = dim + 1;
+        dim += 1;
         if (sz (dim) != 1)
           plane = [plane, dim];
           if (length (plane) == 2)
@@ -102,21 +104,21 @@ function y = rotdim (x, n, plane)
 
   n = rem (n, 4);
   if (n < 0)
-    n = n + 4;
+    n += 4;
   endif
   if (n == 0)
     y = x;
   elseif (n == 2)
-    y = flipdim (flipdim (x, plane(1)), plane(2));
+    y = flip (flip (x, plane(1)), plane(2));
   elseif (n == 1 || n == 3)
     perm = 1:nd;
     perm(plane(1)) = plane(2);
     perm(plane(2)) = plane(1);
     y = permute (x, perm);
     if (n == 1)
-      y = flipdim (y, min (plane));
+      y = flip (y, min (plane));
     else
-      y = flipdim (y, max (plane));
+      y = flip (y, max (plane));
     endif
   else
     error ("rotdim: internal error!");
@@ -152,8 +154,8 @@ endfunction
 %!assert (rotdim (m, 3), rotdim (m, -1))
 %!assert (rotdim (m, 1), rotdim (m))
 
-## FIXME -- we need tests for multidimensional arrays and different
-## values of PLANE.
+## FIXME: We need tests for multidimensional arrays
+##        and different values of PLANE.
 
 %!error rotdim ()
 %!error rotdim (1, 2, 3, 4)
