@@ -1,4 +1,4 @@
-## Copyright (C) 2007-2013 David Bateman
+## Copyright (C) 2007-2016 David Bateman
 ## Copyright (C) 2010 VZLU Prague
 ##
 ## This file is part of Octave.
@@ -18,27 +18,26 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} structfun (@var{func}, @var{S})
-## @deftypefnx {Function File} {[@var{A}, @dots{}] =} structfun (@dots{})
-## @deftypefnx {Function File} {} structfun (@dots{}, "ErrorHandler", @var{errfunc})
-## @deftypefnx {Function File} {} structfun (@dots{}, "UniformOutput", @var{val})
+## @deftypefn  {} {} structfun (@var{func}, @var{S})
+## @deftypefnx {} {[@var{A}, @dots{}] =} structfun (@dots{})
+## @deftypefnx {} {} structfun (@dots{}, "ErrorHandler", @var{errfunc})
+## @deftypefnx {} {} structfun (@dots{}, "UniformOutput", @var{val})
 ##
 ## Evaluate the function named @var{name} on the fields of the structure
 ## @var{S}.  The fields of @var{S} are passed to the function @var{func}
 ## individually.
 ##
-## @code{structfun} accepts an arbitrary function @var{func} in the form of
-## an inline function, function handle, or the name of a function (in a
-## character string).  In the case of a character string argument, the
-## function must accept a single argument named @var{x}, and it must return
-## a string value.  If the function returns more than one argument, they are
-## returned as separate output variables.
+## @code{structfun} accepts an arbitrary function @var{func} in the form of an
+## inline function, function handle, or the name of a function (in a character
+## string).  In the case of a character string argument, the function must
+## accept a single argument named @var{x}, and it must return a string value.
+## If the function returns more than one argument, they are returned as
+## separate output variables.
 ##
-## If the parameter @qcode{"UniformOutput"} is set to true (the default),
-## then the function must return a single element which will be concatenated
-## into the return value.  If @qcode{"UniformOutput"} is false, the outputs
-## are placed into a structure with the same fieldnames as the input
-## structure.
+## If the parameter @qcode{"UniformOutput"} is set to true (the default), then
+## the function must return a single element which will be concatenated into
+## the return value.  If @qcode{"UniformOutput"} is false, the outputs are
+## placed into a structure with the same fieldnames as the input structure.
 ##
 ## @example
 ## @group
@@ -54,9 +53,8 @@
 ## @end group
 ## @end example
 ##
-## Given the parameter @qcode{"ErrorHandler"}, @var{errfunc} defines a
-## function to call in case @var{func} generates an error.  The form of the
-## function is
+## Given the parameter @qcode{"ErrorHandler"}, @var{errfunc} defines a function
+## to call in case @var{func} generates an error.  The form of the function is
 ##
 ## @example
 ## function [@dots{}] = errfunc (@var{se}, @dots{})
@@ -106,8 +104,10 @@ function varargout = structfun (func, S, varargin);
   [varargout{:}] = cellfun (func, struct2cell (S), varargin{:});
 
   if (! uniform_output)
-    varargout = cellfun ("cell2struct", varargout, {fieldnames(S)}, {1}, uo_str, false);
+    varargout = cellfun ("cell2struct", varargout, {fieldnames(S)}, {1}, ...
+                         uo_str, false);
   endif
+
 endfunction
 
 
@@ -121,8 +121,8 @@ endfunction
 %! assert (o, l);
 
 %!function [a, b] = __twoouts (x)
-%! a = x + x;
-%! b = x * x;
+%!  a = x + x;
+%!  b = x * x;
 %!endfunction
 
 %!test
