@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2012 Søren Hauberg
+## Copyright (C) 2009-2016 Søren Hauberg
 ##
 ## This file is part of Octave.
 ##
@@ -17,16 +17,20 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} doc_cache_create (@var{out_file}, @var{directory})
-## Generate documentation caches for all functions in a given directory.
+## @deftypefn  {} {} doc_cache_create (@var{out_file}, @var{directory})
+## @deftypefnx {} {} doc_cache_create (@var{out_file})
+## @deftypefnx {} {} doc_cache_create ()
+## Generate documentation cache for all functions in @var{directory}.
 ##
-## A documentation cache is generated for all functions in @var{directory}.
-## The
-## resulting cache is saved in the file @var{out_file}.
-## The cache is used to speed up @code{lookfor}.
+## A documentation cache is generated for all functions in @var{directory}
+## which may be a single string or a cell array of strings.  The cache is used
+## to speed up the function @code{lookfor}.
 ##
-## If no directory is given (or it is the empty matrix), a cache for builtin
-## operators, etc. is generated.
+## The cache is saved in the file @var{out_file} which defaults to the value
+## @file{doc-cache} if not given.
+##
+## If no directory is given (or it is the empty matrix), a cache for built-in
+## functions, operators, and keywords is generated.
 ##
 ## @seealso{doc_cache_file, lookfor, path}
 ## @end deftypefn
@@ -55,15 +59,17 @@ function doc_cache_create (out_file = "doc-cache", directory = [])
 
   ## Save cache
   if (! isempty (cache))
+     save_header_format_string (["# doc-cache created by Octave " OCTAVE_VERSION], "local");
      save ("-text", out_file, "cache");
   endif
 
 endfunction
 
 function [text, first_sentence, status] = handle_function (f, text, format)
+
   first_sentence = "";
-  ## Skip functions that start with __ as these shouldn't be searched by lookfor
-  if (length (f) > 2 && all (f (1:2) == "_"))
+  ## Skip internal functions starting with "__"
+  if (strncmp (f, "__", 2))
     status = 1;
     return;
   endif
@@ -88,9 +94,11 @@ function [text, first_sentence, status] = handle_function (f, text, format)
 
   ## Get first sentence of help text
   first_sentence = get_first_help_sentence (f);
+
 endfunction
 
 function cache = create_cache (list)
+
   cache = {};
 
   ## For each function:
@@ -112,6 +120,7 @@ function cache = create_cache (list)
     cache(2, end) = text;
     cache(3, end) = first_sentence;
   endfor
+
 endfunction
 
 function cache = gen_doc_cache_in_dir (directory)
@@ -123,7 +132,7 @@ function cache = gen_doc_cache_in_dir (directory)
   if (! iscell (directory))
     directory = {directory};
   endif
-  dirs_notpath = {directory{!dir_in_path}};
+  dirs_notpath = {directory{! dir_in_path}};
 
   ## add them
   if (! isempty (dirs_notpath))
@@ -137,7 +146,7 @@ function cache = gen_doc_cache_in_dir (directory)
   ## concatenate results
   cache = [cache{:}];
 
-  ## remove dirs form path
+  ## remove dirs from path
   if (! isempty (dirs_notpath))
     rmpath (dirs_notpath{:});
   endif
@@ -145,16 +154,18 @@ function cache = gen_doc_cache_in_dir (directory)
 endfunction
 
 function cache = gen_builtin_cache ()
+
   operators = __operators__ ();
   keywords = __keywords__ ();
   builtins = __builtins__ ();
   list = {operators{:}, keywords{:}, builtins{:}};
 
   cache = create_cache (list);
+
 endfunction
 
 
-%% No true tests desirable for this function.
-%% Test input validation
+## No true tests desirable for this function.
+## Test input validation
 %!error doc_cache_create (1)
 
