@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2012 Søren Hauberg
+## Copyright (C) 2009-2016 Søren Hauberg
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{text}, @var{status}] =} __strip_html_tags__ (@var{html_text})
+## @deftypefn {} {[@var{text}, @var{status}] =} __strip_html_tags__ (@var{html_text})
 ## Undocumented internal function.
 ## @end deftypefn
 
@@ -25,6 +25,7 @@
 ## function.
 
 function [text, status] = __strip_html_tags__ (html_text)
+
   start = find (html_text == "<");
   stop  = find (html_text == ">");
   if (length (start) == length (stop))
@@ -40,19 +41,21 @@ function [text, status] = __strip_html_tags__ (html_text)
     text = "";
     status = 1;
   endif
+
 endfunction
 
 ## This function removes end-lines (\n) that makes printing look bad
 function text = strip_superfluous_endlines (text)
+
   ## Find groups of end-lines
   els = find (text == "\n");
   dels = diff (els);
   groups = [els(1), 1]; # list containing [start, length] of each group
   for k = 1:length (dels)
     if (dels (k) == 1)
-      groups (end, 2) ++;
+      groups(end, 2) ++;
     else
-      groups (end+1, 1:2) = [els(k+1), 1];
+      groups(end+1, 1:2) = [els(k+1), 1];
     endif
   endfor
 
@@ -60,23 +63,24 @@ function text = strip_superfluous_endlines (text)
 
   ## Remove end-lines in the beginning
   if (groups (1, 1) == 1)
-    keep (1:groups (1, 2)) = false;
+    keep(1:groups (1, 2)) = false;
   endif
 
   ## Remove end-lines from the end
-  if (sum (groups (end, :)) - 1 == length (text))
-    keep (groups (end, 1):end) = false;
+  if (sum (groups(end, :)) - 1 == length (text))
+    keep(groups(end, 1):end) = false;
   endif
 
   ## Remove groups of end-lines with more than 3 end-lines next to each other
   idx = find (groups (:, 2) >= 3);
   for k = 1:length (idx)
-    start = groups (idx (k), 1);
-    stop = start + groups (idx (k), 2) - 1;
-    keep (start+2:stop) = false;
+    start = groups(idx(k), 1);
+    stop = start + groups(idx(k), 2) - 1;
+    keep(start+2:stop) = false;
   endfor
 
   ## Actually remove the elements
-  text = text (keep);
+  text = text(keep);
+
 endfunction
 
