@@ -1,4 +1,4 @@
-## Copyright (C) 1999-2015 Kai Habel
+## Copyright (C) 1999-2016 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,8 +17,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{map} =} copper ()
-## @deftypefnx {Function File} {@var{map} =} copper (@var{n})
+## @deftypefn  {} {@var{map} =} copper ()
+## @deftypefnx {} {@var{map} =} copper (@var{n})
 ## Create color colormap.  This colormap varies from black to a light copper
 ## tone.
 ##
@@ -29,9 +29,6 @@
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-## PKG_ADD: colormap ("register", "copper");
-## PKG_DEL: colormap ("unregister", "copper");
-
 function map = copper (n = rows (colormap ()))
 
   if (nargin > 1)
@@ -58,8 +55,9 @@ endfunction
 
 
 %!demo
-%! ## Show the 'copper' colormap as an image
-%! image (1:64, linspace (0, 1, 64), repmat ((1:64)', 1, 64));
-%! axis ([1, 64, 0, 1], "ticy", "xy");
-%! colormap (copper (64));
-
+%! ## Show the 'copper' colormap profile and as an image
+%! cmap = copper (256);
+%! subplot (2, 1, 1);
+%!  rgbplot (cmap, "composite");
+%! subplot (2, 1, 2);
+%!  rgbplot (cmap);
