@@ -17,11 +17,11 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{img} =} gray2ind (@var{I})
-## @deftypefnx {Function File} {@var{img} =} gray2ind (@var{I}, @var{n})
-## @deftypefnx {Function File} {@var{img} =} gray2ind (@var{BW})
-## @deftypefnx {Function File} {@var{img} =} gray2ind (@var{BW}, @var{n})
-## @deftypefnx {Function File} {[@var{img}, @var{map}] =} gray2ind (@dots{})
+## @deftypefn  {} {@var{img} =} gray2ind (@var{I})
+## @deftypefnx {} {@var{img} =} gray2ind (@var{I}, @var{n})
+## @deftypefnx {} {@var{img} =} gray2ind (@var{BW})
+## @deftypefnx {} {@var{img} =} gray2ind (@var{BW}, @var{n})
+## @deftypefnx {} {[@var{img}, @var{map}] =} gray2ind (@dots{})
 ## Convert a grayscale or binary intensity image to an indexed image.
 ##
 ## The indexed image will consist of @var{n} different intensity values.
@@ -98,9 +98,9 @@ endfunction
 %!        uint8 ([0 0 1 254 255 255]))
 
 %!test
-%! assert (class (gray2ind ([0.0 0.5 1.0], 255)), "uint8")
-%! assert (class (gray2ind ([0.0 0.5 1.0], 256)), "uint8")
-%! assert (class (gray2ind ([0.0 0.5 1.0], 257)), "uint16")
+%! assert (class (gray2ind ([0.0 0.5 1.0], 255)), "uint8");
+%! assert (class (gray2ind ([0.0 0.5 1.0], 256)), "uint8");
+%! assert (class (gray2ind ([0.0 0.5 1.0], 257)), "uint16");
 
 ## Test input validation
 %!error gray2ind ()
