@@ -1,4 +1,4 @@
-## Copyright (C) 1999-2012 Kai Habel
+## Copyright (C) 1999-2016 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,10 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} hsv (@var{n})
+## @deftypefn {} {} hsv (@var{n})
 ## Create color colormap.  This colormap begins with red, changes through
 ## yellow, green, cyan, blue, and magenta, before returning to red.
+##
 ## It is useful for displaying periodic functions.  The map is obtained by
 ## linearly varying the hue through all possible values while keeping constant
 ## maximum saturation and value.  The equivalent code is
@@ -32,20 +33,14 @@
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-## PKG_ADD: colormap ("register", "hsv");
-## PKG_DEL: colormap ("unregister", "hsv");
+function map = hsv (n = rows (colormap ()))
 
-function map = hsv (n)
-
-  if (nargin == 0)
-    n = rows (colormap);
-  elseif (nargin == 1)
-    if (! isscalar (n))
-      error ("hsv: N must be a scalar");
-    endif
-  else
+  if (nargin > 1)
     print_usage ();
+  elseif (! isscalar (n))
+    error ("hsv: N must be a scalar");
   endif
+  n = double (n);
 
   if (n == 1)
     map = [1, 0, 0];
@@ -59,9 +54,11 @@ function map = hsv (n)
 endfunction
 
 
+## A better demo of this colormap would be to plot the hsv values.
 %!demo
-%! ## Show the 'hsv' colormap as an image
-%! image (1:64, linspace (0, 1, 64), repmat ((1:64)', 1, 64));
-%! axis ([1, 64, 0, 1], "ticy", "xy");
-%! colormap (hsv (64));
-
+%! ## Show the 'hsv' colormap profile and as an image
+%! cmap = hsv (256);
+%! subplot (2, 1, 1);
+%!  rgbplot (cmap, "composite");
+%! subplot (2, 1, 2);
+%!  rgbplot (cmap);
