@@ -1,4 +1,4 @@
-## Copyright (C) 2000-2012 Kai Habel
+## Copyright (C) 2000-2016 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,10 +17,13 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{map} =} pink ()
-## @deftypefnx {Function File} {@var{map} =} pink (@var{n})
+## @deftypefn  {} {@var{map} =} pink ()
+## @deftypefnx {} {@var{map} =} pink (@var{n})
 ## Create color colormap.  This colormap varies from black to white with
-## shades of gray-pink.  It gives a sepia tone when used on grayscale images.
+## shades of gray-pink.
+##
+## This colormap gives a sepia tone when used on grayscale images.
+##
 ## The argument @var{n} must be a scalar.
 ## If unspecified, the length of the current colormap, or 64, is used.
 ## @seealso{colormap}
@@ -28,19 +31,12 @@
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-## PKG_ADD: colormap ("register", "pink");
-## PKG_DEL: colormap ("unregister", "pink");
+function map = pink (n = rows (colormap ()))
 
-function map = pink (n)
-
-  if (nargin == 0)
-    n = rows (colormap);
-  elseif (nargin == 1)
-    if (! isscalar (n))
-      error ("pink: N must be a scalar");
-    endif
-  else
+  if (nargin > 1)
     print_usage ();
+  elseif (! isscalar (n))
+    error ("pink: N must be a scalar");
   endif
 
   if (n == 1)
@@ -74,8 +70,9 @@ endfunction
 
 
 %!demo
-%! ## Show the 'pink' colormap as an image
-%! image (1:64, linspace (0, 1, 64), repmat ((1:64)', 1, 64));
-%! axis ([1, 64, 0, 1], "ticy", "xy");
-%! colormap (pink (64));
-
+%! ## Show the 'pink' colormap profile and as an image
+%! cmap = pink (256);
+%! subplot (2, 1, 1);
+%!  rgbplot (cmap, "composite");
+%! subplot (2, 1, 2);
+%!  rgbplot (cmap);
