@@ -1,4 +1,4 @@
-## Copyright (C) 2006-2013 David Bateman and Marco Caliari
+## Copyright (C) 2006-2016 David Bateman and Marco Caliari
 ## Copyright (C) 2009 VZLU Prague
 ##
 ## This file is part of Octave.
@@ -18,16 +18,19 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{n} =} normest (@var{A})
-## @deftypefnx {Function File} {@var{n} =} normest (@var{A}, @var{tol})
-## @deftypefnx {Function File} {[@var{n}, @var{c}] =} normest (@dots{})
-## Estimate the 2-norm of the matrix @var{A} using a power series
-## analysis.  This is typically used for large matrices, where the cost
-## of calculating @code{norm (@var{A})} is prohibitive and an approximation
-## to the 2-norm is acceptable.
+## @deftypefn  {} {@var{n} =} normest (@var{A})
+## @deftypefnx {} {@var{n} =} normest (@var{A}, @var{tol})
+## @deftypefnx {} {[@var{n}, @var{c}] =} normest (@dots{})
+## Estimate the 2-norm of the matrix @var{A} using a power series analysis.
+##
+## This is typically used for large matrices, where the cost of calculating
+## @code{norm (@var{A})} is prohibitive and an approximation to the 2-norm is
+## acceptable.
 ##
 ## @var{tol} is the tolerance to which the 2-norm is calculated.  By default
-## @var{tol} is 1e-6.  @var{c} returns the number of iterations needed for
+## @var{tol} is 1e-6.
+##
+## The optional output @var{c} returns the number of iterations needed for
 ## @code{normest} to converge.
 ## @end deftypefn
 
@@ -52,7 +55,7 @@ function [n, c] = normest (A, tol = 1e-6)
   tol = max (tol, eps (class (A)));
   ## Set random number generator to depend on target matrix
   v = rand ("state");
-  rand ("state", trace (A));
+  rand ("state", full (trace (A)));
   ncols = columns (A);
   ## Randomize y to avoid bad guesses for important matrices.
   y = rand (ncols, 1);
@@ -65,7 +68,7 @@ function [n, c] = normest (A, tol = 1e-6)
     if (normx == 0)
       x = rand (ncols, 1);
     else
-      x = x / normx;
+      x /= normx;
     endif
     y = A' * x;
     n = norm (y);
@@ -73,6 +76,7 @@ function [n, c] = normest (A, tol = 1e-6)
   until (abs (n - n0) <= tol * n)
 
   rand ("state", v);    # restore state of random number generator
+
 endfunction
 
 
@@ -84,7 +88,7 @@ endfunction
 %! A = rand (10);
 %! assert (normest (A), norm (A), 1e-6);
 
-%% Test input validation
+## Test input validation
 %!error normest ()
 %!error normest (1, 2, 3)
 %!error normest ([true true])
