@@ -1,4 +1,4 @@
-## Copyright (C) 2006-2011 John W. Eaton
+## Copyright (C) 2006-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,8 +17,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{val} =} ls_command ()
-## @deftypefnx {Function File} {@var{old_val} =} ls_command (@var{new_val})
+## @deftypefn  {} {@var{val} =} ls_command ()
+## @deftypefnx {} {@var{old_val} =} ls_command (@var{new_val})
 ## Query or set the shell command used by Octave's @code{ls} command.
 ## @seealso{ls}
 ## @end deftypefn
@@ -47,7 +47,7 @@ function old_cmd = ls_command (cmd)
       if (ischar (cmd))
         __ls_command__ = cmd;
       else
-        error ("ls_command: expecting argument to be a character string");
+        error ("ls_command: argument must be a character string");
       endif
     endif
 
@@ -60,8 +60,10 @@ endfunction
 %! cmd = ls_command ();
 %! assert (ischar (cmd));
 %! if (ispc () && ! isunix ())
-%!   assert (cmd(1:3), "dir"); 
+%!   assert (cmd(1:3), "dir");
 %! else
-%!   assert (cmd(1:2), "ls"); 
+%!   assert (cmd(1:2), "ls");
 %! endif
 
+%!error <argument must be a character string> ls_command (123)
+
