@@ -1,4 +1,4 @@
-## Copyright (C) 2008-2012 David Bateman
+## Copyright (C) 2008-2016 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,13 +17,14 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} namelengthmax ()
-## Return the @sc{matlab} compatible maximum variable name length.  Octave is
-## capable of storing strings up to @math{2^{31} - 1} in length.
-## However for @sc{matlab} compatibility all variable, function,
-## and structure field names should be shorter than the length supplied by
-## @code{namelengthmax}.  In particular variables stored to a @sc{matlab} file
-## format will have their names truncated to this length.
+## @deftypefn {} {} namelengthmax ()
+## Return the @sc{matlab} compatible maximum variable name length.
+##
+## Octave is capable of storing strings up to @math{2^{31} - 1} in length.
+## However for @sc{matlab} compatibility all variable, function, and structure
+## field names should be shorter than the length returned by
+## @code{namelengthmax}.  In particular, variables stored to a @sc{matlab} file
+## format (@file{*.mat}) will have their names truncated to this length.
 ## @end deftypefn
 
 function n = namelengthmax ()
