@@ -1,4 +1,4 @@
-## Copyright (C) 2007-2013 John W. Eaton
+## Copyright (C) 2007-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,13 +17,15 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Command} {} news
-## @deftypefnx {Command} {} news @var{package}
+## @deftypefn  {} {} news
+## @deftypefnx {} {} news @var{package}
 ## Display the current NEWS file for Octave or an installed package.
 ##
 ## When called without an argument, display the NEWS file for Octave.
+##
 ## When given a package name @var{package}, display the current NEWS file for
 ## that package.
+## @seealso{ver, pkg}
 ## @end deftypefn
 
 function news (package = "octave")
