@@ -1,4 +1,4 @@
-## Copyright (C) 2008-2013 David Bateman
+## Copyright (C) 2008-2016 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,17 +17,17 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} clabel (@var{c}, @var{h})
-## @deftypefnx {Function File} {} clabel (@var{c}, @var{h}, @var{v})
-## @deftypefnx {Function File} {} clabel (@var{c}, @var{h}, "manual")
-## @deftypefnx {Function File} {} clabel (@var{c})
-## @deftypefnx {Function File} {} clabel (@dots{}, @var{prop}, @var{val}, @dots{})
-## @deftypefnx {Function File} {@var{h} =} clabel (@dots{})
+## @deftypefn  {} {} clabel (@var{c}, @var{h})
+## @deftypefnx {} {} clabel (@var{c}, @var{h}, @var{v})
+## @deftypefnx {} {} clabel (@var{c}, @var{h}, "manual")
+## @deftypefnx {} {} clabel (@var{c})
+## @deftypefnx {} {} clabel (@dots{}, @var{prop}, @var{val}, @dots{})
+## @deftypefnx {} {@var{h} =} clabel (@dots{})
 ## Add labels to the contours of a contour plot.
 ##
 ## The contour levels are specified by the contour matrix @var{c} which is
 ## returned by @code{contour}, @code{contourc}, @code{contourf}, and
-## @code{contour3}.  Contour labels are rotated to match the local line 
+## @code{contour3}.  Contour labels are rotated to match the local line
 ## orientation and centered on the line.  The position of labels along the
 ## contour line is chosen randomly.
 ##
@@ -105,7 +105,7 @@ function h = clabel (c, varargin)
     have_labelspacing = true;
     label_spacing = varargin{2*idx};
     varargin(2*idx+(-1:0)) = [];
-  endif    
+  endif
 
   if (have_hg)
     if (! isempty (v))
@@ -127,7 +127,7 @@ function h = clabel (c, varargin)
       set (htmp, varargin{:});
     endif
   else
-    htmp =  __clabel__ (c, v, hparent, label_spacing, [], varargin{:});
+    htmp = __clabel__ (c, v, hparent, label_spacing, [], varargin{:});
   endif
 
   if (nargout > 0)
@@ -139,15 +139,15 @@ endfunction
 
 %!demo
 %! clf;
-%! colormap ('default');
+%! colormap ("default");
 %! [c, h] = contour (peaks (), -4:6);
-%! clabel (c, h, -4:2:6, 'fontsize', 12);
-%! title ('clabel() labeling every other contour');
+%! clabel (c, h, -4:2:6, "fontsize", 12);
+%! title ("clabel() labeling every other contour");
 
 %!demo
 %! clf;
-%! colormap ('default');
+%! colormap ("default");
 %! [c, h] = contourf (peaks (), -7:6);
-%! clabel (c, h, -6:2:6, 'fontsize', 12);
-%! title ('clabel() labeling every other contour');
+%! clabel (c, h, -6:2:6, "fontsize", 12);
+%! title ("clabel() labeling every other contour");
 
