@@ -1,4 +1,4 @@
-## Copyright (C) 2012 John W. Eaton
+## Copyright (C) 2012-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,8 +17,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} prefsfile ()
-## Undocumented internal function.
+## @deftypefn {} {} prefsfile ()
+## Return the full path and name of the file containing Octave preferences.
 ## @end deftypefn
 
 ## Author: jwe
@@ -26,11 +26,6 @@
 function retval = prefsfile ()
 
   retval = [prefdir() filesep() ".octave_prefs"];
-  
+
 endfunction
 
-
-%% Testing these functions will require some care to avoid wiping out
-%% existing (or creating unwanted) preferences for the user running the
-%% tests.
-
