@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2012 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{pval}, @var{lm}] =} arch_test (@var{y}, @var{x}, @var{p})
+## @deftypefn {} {[@var{pval}, @var{lm}] =} arch_test (@var{y}, @var{x}, @var{p})
 ## For a linear regression model
 ##
 ## @example
@@ -74,8 +74,8 @@ function [pval, lm] = arch_test (y, x, p)
   if (! (isvector (y)))
     error ("arch_test: Y must be a vector");
   endif
-  T   = length (y);
-  y   = reshape (y, T, 1);
+  T = length (y);
+  y = reshape (y, T, 1);
   [rx, cx] = size (x);
   if ((rx == 1) && (cx == 1))
     x = autoreg_matrix (y, x);
