@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2012 Friedrich Leisch
+## Copyright (C) 1995-2016 Friedrich Leisch
 ##
 ## This file is part of Octave.
 ##
@@ -17,23 +17,24 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{d}, @var{dd}] =} diffpara (@var{x}, @var{a}, @var{b})
+## @deftypefn {} {[@var{d}, @var{dd}] =} diffpara (@var{x}, @var{a}, @var{b})
 ## Return the estimator @var{d} for the differencing parameter of an
 ## integrated time series.
 ##
 ## The frequencies from @math{[2*pi*a/t, 2*pi*b/T]} are used for the
 ## estimation.  If @var{b} is omitted, the interval
-## @math{[2*pi/T, 2*pi*a/T]} is used.  If both @var{b} and @var{a} are
-## omitted then @math{a = 0.5 * sqrt (T)} and @math{b = 1.5 * sqrt (T)}
-## is used, where @math{T} is the sample size.  If @var{x} is a matrix,
-## the differencing parameter of each column is estimated.
+## @math{[2*pi/T, 2*pi*a/T]} is used.  If both @var{b} and @var{a} are omitted
+## then @math{a = 0.5 * sqrt (T)} and @math{b = 1.5 * sqrt (T)} is used, where
+## @math{T} is the sample size.  If @var{x} is a matrix, the differencing
+## parameter of each column is estimated.
 ##
-## The estimators for all frequencies in the intervals
-## described above is returned in @var{dd}.  The value of @var{d} is
-## simply the mean of @var{dd}.
+## The estimators for all frequencies in the intervals described above is
+## returned in @var{dd}.
 ##
-## Reference: P.J. Brockwell & R.A. Davis. @cite{Time Series:
-## Theory and Methods}. Springer 1987.
+## The value of @var{d} is simply the mean of @var{dd}.
+##
+## Reference: @nospell{P.J. Brockwell & R.A. Davis}. @cite{Time Series:
+## Theory and Methods}. @nospell{Springer} 1987.
 ## @end deftypefn
 
 ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
@@ -41,23 +42,23 @@
 
 function [d, dd] = diffpara (x, a, b)
 
-  if ((nargin < 1) || (nargin > 3))
+  if (nargin < 1 || nargin > 3)
     print_usage ();
+  endif
+
+  if (isvector (x))
+    n = length (x);
+    k = 1;
+    x = reshape (x, n, 1);
   else
-    if (isvector (x))
-      n = length (x);
-      k = 1;
-      x = reshape (x, n, 1);
-    else
-      [n, k] = size (x);
-    endif
-    if (nargin == 1)
-      a = 0.5 * sqrt (n);
-      b = 1.5 * sqrt (n);
-    elseif (nargin == 2)
-      b = a;
-      a = 1;
-    endif
+    [n, k] = size (x);
+  endif
+  if (nargin == 1)
+    a = 0.5 * sqrt (n);
+    b = 1.5 * sqrt (n);
+  elseif (nargin == 2)
+    b = a;
+    a = 1;
   endif
 
   if (! (isscalar (a) && isscalar (b)))
