@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2013 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -17,10 +17,10 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} cov (@var{x})
-## @deftypefnx {Function File} {} cov (@var{x}, @var{opt})
-## @deftypefnx {Function File} {} cov (@var{x}, @var{y})
-## @deftypefnx {Function File} {} cov (@var{x}, @var{y}, @var{opt})
+## @deftypefn  {} {} cov (@var{x})
+## @deftypefnx {} {} cov (@var{x}, @var{opt})
+## @deftypefnx {} {} cov (@var{x}, @var{y})
+## @deftypefnx {} {} cov (@var{x}, @var{y}, @var{opt})
 ## Compute the covariance matrix.
 ##
 ## If each row of @var{x} and @var{y} is an observation, and each column is
@@ -56,12 +56,14 @@
 ##   normalize with @math{N}, this provides the second moment around the mean
 ## @end table
 ##
-## @sc{matlab} compatibility: Octave always computes the covariance matrix.
-## For two inputs, however, @sc{matlab} will calculate
-## @code{cov (@var{x}(:), @var{y}(:))} whenever the number of elements in
-## @var{x} and @var{y} are equal.  This will result in a scalar rather than
-## a matrix output.  Code relying on this odd definition will need to be
-## changed when running in Octave.
+## Compatibility Note:: Octave always treats rows of @var{x} and @var{y}
+## as multivariate random variables.
+## For two inputs, however, @sc{matlab} treats @var{x} and @var{y} as two
+## univariate distributions regardless of their shapes, and will calculate
+## @code{cov ([@var{x}(:), @var{y}(:)])} whenever the number of elements in
+## @var{x} and @var{y} are equal.  This will result in a 2x2 matrix.
+## Code relying on @sc{matlab}'s definition will need to be changed when
+## running in Octave.
 ## @seealso{corr}
 ## @end deftypefn
 
@@ -108,7 +110,7 @@ function c = cov (x, y = [], opt = 0)
 
   if (nargin == 1 || isscalar (y))
     x = center (x, 1);
-    c = conj (x' * x / (n - 1 + opt));
+    c = x' * x / (n - 1 + opt);
   else
     if (isrow (y))
       y = y.';
@@ -118,7 +120,7 @@ function c = cov (x, y = [], opt = 0)
     endif
     x = center (x, 1);
     y = center (y, 1);
-    c = conj (x' * y / (n - 1 + opt));
+    c = x' * y / (n - 1 + opt);
   endif
 
 endfunction
@@ -161,7 +163,7 @@ endfunction
 %! c = cov (x, 1);
 %! assert (c, 2);
 
-%% Test input validation
+## Test input validation
 %!error cov ()
 %!error cov (1, 2, 3, 4)
 %!error cov ([1; 2], ["A", "B"])
