@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2013 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,13 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} iqr (@var{x})
-## @deftypefnx {Function File} {} iqr (@var{x}, @var{dim})
+## @deftypefn  {} {} iqr (@var{x})
+## @deftypefnx {} {} iqr (@var{x}, @var{dim})
 ## Return the interquartile range, i.e., the difference between the upper
-## and lower quartile of the input data.  If @var{x} is a matrix, do the
-## above for first non-singleton dimension of @var{x}.
+## and lower quartile of the input data.
+##
+## If @var{x} is a matrix, do the above for first non-singleton dimension of
+## @var{x}.
 ##
 ## If the optional argument @var{dim} is given, operate along this dimension.
 ##
@@ -71,7 +73,7 @@ function y = iqr (x, dim)
     offset2 = 0;
     while (offset > stride)
       offset -= stride;
-      offset2++;
+      offset2 += 1;
     endwhile
     offset += offset2 * stride * n;
     rng = [0 : n-1] * stride + offset;
@@ -85,10 +87,11 @@ endfunction
 %!assert (iqr (1:101), 50)
 %!assert (iqr (single (1:101)), single (50))
 
-%%!test
-%%! x = [1:100];
-%%! n = iqr (x, 0:10);
-%%! assert (n, [repmat(100, 1, 10), 1]);
+## FIXME: iqr throws horrible error when running across a dimension that is 1.
+%!test
+%! x = [1:100]';
+%! assert (iqr (x, 1), 50);
+%! assert (iqr (x', 2), 50);
 
 %!error iqr ()
 %!error iqr (1, 2, 3)
