@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2012 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ## Copyright (C) 2009 Jaroslav Hajek
 ##
 ## This file is part of Octave.
@@ -18,9 +18,11 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} meansq (@var{x})
-## @deftypefnx {Function File} {} meansq (@var{x}, @var{dim})
+## @deftypefn  {} {} meansq (@var{x})
+## @deftypefnx {} {} meansq (@var{x}, @var{dim})
 ## Compute the mean square of the elements of the vector @var{x}.
+##
+## The mean square is defined as
 ## @tex
 ## $$
 ## {\rm meansq} (x) = {\sum_{i=1}^N {x_i}^2 \over N}
@@ -31,7 +33,7 @@
 ##
 ## @example
 ## @group
-## std (x) = 1/N SUM_i x(i)^2
+## meansq (x) = 1/N SUM_i x(i)^2
 ## @end group
 ## @end example
 ##
@@ -62,13 +64,12 @@ function y = meansq (x, dim)
     ## Find the first non-singleton dimension.
     (dim = find (sz > 1, 1)) || (dim = 1);
   else
-    if (!(isscalar (dim) && dim == fix (dim))
-        || !(1 <= dim && dim <= nd))
+    if (! (isscalar (dim) && dim == fix (dim) && dim > 0))
       error ("mean: DIM must be an integer and a valid dimension");
     endif
   endif
 
-  y = sumsq (x, dim) / sz(dim);
+  y = sumsq (x, dim) / size (x, dim);
 
 endfunction
 
@@ -77,13 +78,13 @@ endfunction
 %!assert (meansq (single (1:5)), single (11))
 %!assert (meansq (magic (4)), [94.5, 92.5, 92.5, 94.5])
 %!assert (meansq (magic (4), 2), [109.5; 77.5; 77.5; 109.5])
+%!assert (meansq ([1 2], 3), [1 4])
 
-%% Test input validation
+## Test input validation
 %!error meansq ()
 %!error meansq (1, 2, 3)
-%!error meansq (['A'; 'B'])
-%!error meansq (1, ones (2,2))
-%!error meansq (1, 1.5)
-%!error meansq (1, 0)
-%!error meansq (1, 3)
+%!error <X must be a numeric> meansq (['A'; 'B'])
+%!error <DIM must be an integer> meansq (1, ones (2,2))
+%!error <DIM must be an integer> meansq (1, 1.5)
+%!error <DIM must be .* a valid dimension> meansq (1, 0)
 
