@@ -1,5 +1,5 @@
 ## Copyright (C) 2012 Rik Wehbring
-## Copyright (C) 1995-2012 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -18,7 +18,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} betacdf (@var{x}, @var{a}, @var{b})
+## @deftypefn {} {} betacdf (@var{x}, @var{a}, @var{b})
 ## For each element of @var{x}, compute the cumulative distribution function
 ## (CDF) at @var{x} of the Beta distribution with parameters @var{a} and
 ## @var{b}.
@@ -33,7 +33,7 @@ function cdf = betacdf (x, a, b)
     print_usage ();
   endif
 
-  if (!isscalar (a) || !isscalar (b))
+  if (! isscalar (a) || ! isscalar (b))
     [retval, x, a, b] = common_size (x, a, b);
     if (retval > 0)
       error ("betacdf: X, A, and B must be of common size or scalars");
@@ -76,13 +76,13 @@ endfunction
 %!assert (betacdf (x, 1, 2*[0 1 NaN 1 1]), [NaN 0 NaN 1 1])
 %!assert (betacdf ([x(1:2) NaN x(4:5)], 1, 2), [y(1:2) NaN y(4:5)])
 
-%% Test class of input preserved
+## Test class of input preserved
 %!assert (betacdf ([x, NaN], 1, 2), [y, NaN])
 %!assert (betacdf (single ([x, NaN]), 1, 2), single ([y, NaN]))
 %!assert (betacdf ([x, NaN], single (1), 2), single ([y, NaN]))
 %!assert (betacdf ([x, NaN], 1, single (2)), single ([y, NaN]))
 
-%% Test input validation
+## Test input validation
 %!error betacdf ()
 %!error betacdf (1)
 %!error betacdf (1,2)
