@@ -1,5 +1,5 @@
 ## Copyright (C) 2012 Rik Wehbring
-## Copyright (C) 2010-2013 David Bateman
+## Copyright (C) 2010-2016 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -18,10 +18,10 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} discrete_cdf (@var{x}, @var{v}, @var{p})
-## For each element of @var{x}, compute the cumulative distribution
-## function (CDF) at @var{x} of a univariate discrete distribution which
-## assumes the values in @var{v} with probabilities @var{p}.
+## @deftypefn {} {} discrete_cdf (@var{x}, @var{v}, @var{p})
+## For each element of @var{x}, compute the cumulative distribution function
+## (CDF) at @var{x} of a univariate discrete distribution which assumes the
+## values in @var{v} with probabilities @var{p}.
 ## @end deftypefn
 
 function cdf = discrete_cdf (x, v, p)
@@ -48,7 +48,7 @@ function cdf = discrete_cdf (x, v, p)
     cdf = NaN (size (x));
   endif
 
-  k = !isnan (x);
+  k = ! isnan (x);
   [vs, vi] = sort (v);
   cdf(k) = [0 ; cumsum(p(vi))](lookup (vs, x(k)) + 1);
 
@@ -62,12 +62,12 @@ endfunction
 %! y = [0 0.1 0.6 1 1];
 %!assert (discrete_cdf ([x, NaN], v, p), [y, NaN], eps)
 
-%% Test class of input preserved
+## Test class of input preserved
 %!assert (discrete_cdf (single ([x, NaN]), v, p), single ([y, NaN]), 2*eps ("single"))
 %!assert (discrete_cdf ([x, NaN], single (v), p), single ([y, NaN]), 2*eps ("single"))
 %!assert (discrete_cdf ([x, NaN], v, single (p)), single ([y, NaN]), 2*eps ("single"))
 
-%% Test input validation
+## Test input validation
 %!error discrete_cdf ()
 %!error discrete_cdf (1)
 %!error discrete_cdf (1,2)
@@ -77,5 +77,5 @@ endfunction
 %!error discrete_cdf (1, ones (2,1), ones (1,1))
 %!error discrete_cdf (1, ones (2,1), [1 -1])
 %!error discrete_cdf (1, ones (2,1), [1 NaN])
-%!error discrete_cdf (1, ones (2,1), [0  0])
+%!error discrete_cdf (1, ones (2,1), [0 0])
 
