@@ -1,5 +1,5 @@
 ## Copyright (C) 2012 Rik Wehbring
-## Copyright (C) 1995-2012 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -18,8 +18,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} unifpdf (@var{x})
-## @deftypefnx {Function File} {} unifpdf (@var{x}, @var{a}, @var{b})
+## @deftypefn  {} {} unifpdf (@var{x})
+## @deftypefnx {} {} unifpdf (@var{x}, @var{a}, @var{b})
 ## For each element of @var{x}, compute the probability density function (PDF)
 ## at @var{x} of the uniform distribution on the interval [@var{a}, @var{b}].
 ##
@@ -35,7 +35,7 @@ function pdf = unifpdf (x, a = 0, b = 1)
     print_usage ();
   endif
 
-  if (!isscalar (a) || !isscalar (b))
+  if (! isscalar (a) || ! isscalar (b))
     [retval, x, a, b] = common_size (x, a, b);
     if (retval > 0)
       error ("unifpdf: X, A, and B must be of common size or scalars");
@@ -75,12 +75,12 @@ endfunction
 %!assert (unifpdf (x, 1, 2*[0 NaN 1 1 1]), [NaN NaN y(3:5)])
 %!assert (unifpdf ([x, NaN], 1, 2), [y, NaN])
 
-%% Test class of input preserved
+## Test class of input preserved
 %!assert (unifpdf (single ([x, NaN]), 1, 2), single ([y, NaN]))
 %!assert (unifpdf (single ([x, NaN]), single (1), 2), single ([y, NaN]))
 %!assert (unifpdf ([x, NaN], 1, single (2)), single ([y, NaN]))
 
-%% Test input validation
+## Test input validation
 %!error unifpdf ()
 %!error unifpdf (1,2)
 %!error unifpdf (1,2,3,4)
