@@ -1,4 +1,4 @@
-## Copyright (C) 1995-2013 Kurt Hornik
+## Copyright (C) 1995-2016 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -17,21 +17,21 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {[@var{pval}, @var{f}, @var{df_num}, @var{df_den}] =} var_test (@var{x}, @var{y}, @var{alt})
+## @deftypefn {} {[@var{pval}, @var{f}, @var{df_num}, @var{df_den}] =} var_test (@var{x}, @var{y}, @var{alt})
 ## For two samples @var{x} and @var{y} from normal distributions with
 ## unknown means and unknown variances, perform an F-test of the null
-## hypothesis of equal variances.  Under the null, the test statistic
-## @var{f} follows an F-distribution with @var{df_num} and @var{df_den}
-## degrees of freedom.
+## hypothesis of equal variances.
 ##
-## With the optional argument string @var{alt}, the alternative of
-## interest can be selected.  If @var{alt} is @qcode{"!="} or
-## @qcode{"<>"}, the null is tested against the two-sided alternative
-## @code{var (@var{x}) != var (@var{y})}.  If @var{alt} is @qcode{">"},
-## the one-sided alternative @code{var (@var{x}) > var (@var{y})} is
-## used.  Similarly for "<", the one-sided alternative @code{var
-## (@var{x}) > var (@var{y})} is used.  The default is the two-sided
-## case.
+## Under the null, the test statistic @var{f} follows an F-distribution with
+## @var{df_num} and @var{df_den} degrees of freedom.
+##
+## With the optional argument string @var{alt}, the alternative of interest
+## can be selected.  If @var{alt} is @qcode{"!="} or @qcode{"<>"}, the null
+## is tested against the two-sided alternative @code{var (@var{x}) != var
+## (@var{y})}.  If @var{alt} is @qcode{">"}, the one-sided alternative
+## @code{var (@var{x}) > var (@var{y})} is used.  Similarly for "<", the
+## one-sided alternative @code{var (@var{x}) > var (@var{y})} is used.  The
+## default is the two-sided case.
 ##
 ## The p-value of the test is returned in @var{pval}.
 ##
@@ -43,7 +43,7 @@
 
 function [pval, f, df_num, df_den] = var_test (x, y, alt)
 
-  if ((nargin < 2) || (nargin > 3))
+  if (nargin < 2 || nargin > 3)
     print_usage ();
   endif
 
@@ -57,7 +57,7 @@ function [pval, f, df_num, df_den] = var_test (x, y, alt)
   cdf    = fcdf (f, df_num, df_den);
 
   if (nargin == 2)
-    alt  = "!=";
+    alt = "!=";
   endif
 
   if (! ischar (alt))
