@@ -1,4 +1,4 @@
-## Copyright (C) 1996-2012 Daniel Calvelo
+## Copyright (C) 1996-2016 Daniel Calvelo
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,11 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} dec2bin (@var{d}, @var{len})
-## Return a binary number corresponding to the non-negative integer
-## @var{d}, as a string of ones and zeros.  For example:
+## @deftypefn {} {} dec2bin (@var{d}, @var{len})
+## Return a binary number corresponding to the non-negative integer @var{d},
+## as a string of ones and zeros.
+##
+## For example:
 ##
 ## @example
 ## @group
@@ -28,12 +30,12 @@
 ## @end group
 ## @end example
 ##
-## If @var{d} is a matrix or cell array, return a string matrix with one
-## row per element in @var{d}, padded with leading zeros to the width of 
-## the largest value.
+## If @var{d} is a matrix or cell array, return a string matrix with one row
+## per element in @var{d}, padded with leading zeros to the width of the
+## largest value.
 ##
-## The optional second argument, @var{len}, specifies the minimum
-## number of digits in the result.
+## The optional second argument, @var{len}, specifies the minimum number of
+## digits in the result.
 ## @seealso{bin2dec, dec2base, dec2hex}
 ## @end deftypefn
 
@@ -57,7 +59,7 @@ endfunction
 %!assert (dec2bin (14, 6), "001110")
 %!assert (dec2bin ({1, 2; 3, 4}), ["001"; "011"; "010"; "100"])
 
-%%Test input validation
+## Test input validation
 %!error dec2bin ()
 %!error dec2bin (1, 2, 3)
 
