@@ -1,13 +1,13 @@
-## Copyright (C) 2010-2012 Ben Abbott
+## Copyright (C) 2010-2016 Ben Abbott
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or (at
+## the Free Software Foundation; either version 3 of the License, or (at
 ## your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful,
+## Octave is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
@@ -17,20 +17,21 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} untabify (@var{t})
-## @deftypefnx {Function File} {} untabify (@var{t}, @var{tw})
-## @deftypefnx {Function File} {} untabify (@var{t}, @var{tw}, @var{deblank})
-## Replace TAB characters in @var{t}, with spaces.
-## The tab width is specified by @var{tw}, or defaults to eight.
-## The input, @var{t}, may be either a 2-D character array, or a cell
-## array of character strings.  The output is the same class
-## as the input.
+## @deftypefn  {} {} untabify (@var{t})
+## @deftypefnx {} {} untabify (@var{t}, @var{tw})
+## @deftypefnx {} {} untabify (@var{t}, @var{tw}, @var{deblank})
+## Replace TAB characters in @var{t} with spaces.
 ##
-## If the optional argument @var{deblank} is true, then the spaces will
-## be removed from the end of the character data.
+## The input, @var{t}, may be either a 2-D character array, or a cell array of
+## character strings.  The output is the same class as the input.
 ##
-## The following example reads a file and writes an untabified version
-## of the same file with trailing spaces stripped.
+## The tab width is specified by @var{tw}, and defaults to eight.
+##
+## If the optional argument @var{deblank} is true, then the spaces will be
+## removed from the end of the character data.
+##
+## The following example reads a file and writes an untabified version of the
+## same file with trailing spaces stripped.
 ##
 ## @example
 ## @group
