@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2012 David Bateman
+## Copyright (C) 2005-2016 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,12 +17,18 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} __printf_assert__ (@dots{})
+## @deftypefn {} {} __printf_assert__ (@dots{})
 ## Undocumented internal function.
 ## @end deftypefn
 
 function __printf_assert__ (varargin)
-  global _assert_printf;
+  global _assert_printf = "";
+
   _assert_printf = cat (2, _assert_printf, sprintf (varargin{:}));
+
 endfunction
 
+
+## No test coverage for internal function.  It is tested through calling fcn.
+%!assert (1)
+
