@@ -1,4 +1,4 @@
-## Copyright (C) 2004-2012 Paul Kienzle
+## Copyright (C) 2004-2016 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{e} =} eomday (@var{y}, @var{m})
+## @deftypefn {} {@var{e} =} eomday (@var{y}, @var{m})
 ## Return the last day of the month @var{m} for the year @var{y}.
 ## @seealso{weekday, datenum, datevec, is_leap_year, calendar}
 ## @end deftypefn
@@ -45,7 +45,6 @@ endfunction
 %! e = eomday (y, repmat (2, [1, 100]));
 %! y(find (e == 29))
 
-# tests
 %!assert (eomday ([-4:4],2), [29,28,28,28,29,28,28,28,29])
 %!assert (eomday ([-901,901],2), [28,28])
 %!assert (eomday ([-100,100],2), [28,28])
@@ -58,7 +57,7 @@ endfunction
 %!assert ([1900:1999](find(eomday(1900:1999,2*ones(1,100))==29)), [1904,1908,1912,1916,1920,1924,1928,1932,1936,1940,1944,1948,1952,1956,1960,1964,1968,1972,1976,1980,1984,1988,1992,1996])
 %!assert (eomday ([2004;2005], [2;2]), [29;28])
 
-%% Test input validation
+## Test input validation
 %!error eomday ()
 %!error eomday (1)
 %!error eomday (1,2,3)
